cap cd "C:/Users/laiwz/OneDrive - University of Maryland/Research/anticorruption_civil_servant/jle_final/replication"

global data ./data
global figdir ./figure
global tabdir ./table





*=======================================
*** load data
*=======================================
use ${data}/data_for_analysis, clear

global control exp_unlimited polaff_unlimited educ_vocational educ_college lngdpp
global controlint c.exp_unlimited#i.yr_inspectagcy c.polaff_unlimited#i.yr_inspectagcy c.educ_vocational#i.yr_inspectagcy c.educ_college#i.yr_inspectagcy

gen inspectbranch = inspectagcy*(main==0)
recode yr_inspectagcy (.=0)


**** Balancing panel
fillin agcyid year
gen imputed = _fillin

foreach v of var yr_inspectagcy main provcd {
	bysort agcyid: egen temp = max(`v')
	replace `v' = temp if missing(`v')
	drop temp
}

replace inspectagcy = (year>=yr_inspectagcy)
replace inspectmain = inspectagcy*main


// fill missing comp and covariates
qui reg comp inspectmain $control i.agcyid i.year

/*
foreach v of var $control {
	bysort agcyid (year): replace `v' = `v'[_n-1] if missing(`v') & !missing(`v'[_n-1])
	gsort agcyid -year
	bysort agcyid : replace `v' = `v'[_n-1] if missing(`v') & !missing(`v'[_n-1])
}
*/

foreach v of var $control {
	if "`v'"=="lngdpp" {
		bysort provcd (year): egen temp = mean(`v')
		replace `v' = temp if missing(`v')
		drop temp
	}
	else {
		bysort agcyid (year): egen temp = mean(`v')
		replace `v' = temp if missing(`v')
		drop temp
	}
}

predict temp
replace comp = temp if missing(comp)
drop temp


***** PSM
set seed 2022
xtset agcyid year
sort agcyid year

bysort agcyid (year): gen dcomp = D.comp
bysort agcyid (year): replace dcomp = F.dcomp if year==2012
cap drop everinspected
bysort agcyid: egen everinspected = max(inspectmain)

/// match for cohorts by inspection years
cls
forvalues y=2012/2016 {
	preserve
	keep if inspectmain==0 & year<=`y'

	local match dcomp comp ${control} //matching variables
	collapse (mean) `match' (max) everinspected , by(agcyid)
	
	gen dcomp2 = dcomp^2
	gen comp2 = comp^2
	gen dcomp3 = dcomp^3
	gen comp3 = comp^3
	
	local match `match' dcomp2 comp2 //matching variables
	
	gen Ntp=0
	replace Ntp=1 if everinspected==0
	qui psmatch2 Ntp `match' , caliper(0.01) common noreplacement 
	pstest _pscore `match' if _support & _weight<. , raw treated(everinspected) // balance after matching
	*pstest _pscore `match' , raw treated(everinspected) // balance prior matching
	
	keep if _support & _weight<.
	keep agcyid _weight
	
	tempfile psm`y'
	save `psm`y''
	
	restore
}


forvalues y=2012/2016 {
	preserve
	merge m:1 agcyid using `psm`y'' , keep(3) nogen
	gen pssample = `y'
	save ${data}/psm_`y' , replace
	restore
}



**** Matched Data
openall psm_* , directory("${data}")
keep if _weight<.
gen wght = 1/_weight
cap drop first_inspect never_inspect

duplicates drop agcyid year , force
save ${data}/data_psm , replace

/// erase data
forvalues y=2012/2016 {
	erase ${data}/psm_`y'.dta
}
