cap cd "C:/Users/laiwz/OneDrive - University of Maryland/Research/anticorruption_civil_servant/jle_final/replication"

global data ./data
global figdir ./figure
global tabdir ./table

graph set window fontface "Times New Roman"



*=======================================
**# Table 1: Summary stats
*=======================================
use ${data}/data_for_analysis, clear

global control exp_unlimited polaff_unlimited educ_vocational educ_college educ_grad


**** make a table
lab var examinee "Applicants"
lab var vacancy "Vacancies"
lab var comp "Applicant-to-hire ratio (AHR)"
lab var exp_unlimited "\% Positions: experience unlimited"
lab var polaff_unlimited "\% Positions: political affiliation unlimited"
lab var educ_vocational "\% Positions: > vocational college"
lab var educ_college "\% Positions: > college"
lab var educ_grad "\% Positions: > graduate school"
lab var lngdp "ln(GDP per capita) of work province"


**** Table	
capt prog drop sumstats
program sumstats, eclass
    version 16
    syntax varlist [if] [in], treat(varname) group(varname) [ * ]
    marksample touse
    markout `touse' `treat' `group'
	
    tempname mu_10 mu_11 sd_10 sd_11 d_1 d_1_se ///
			 mu_00 mu_01 sd_00 sd_01 d_0 d_0_se ///
			 dd dd_se dd_p
			 
    foreach var of local varlist {
	
        /// high intensity group
		qui ttest `var' if `touse' & `treat'==1 , by(`group')
        mat `mu_10' = nullmat(`mu_10') , r(mu_1)
        mat `mu_11' = nullmat(`mu_11') , r(mu_2)
		mat `sd_10' = nullmat(`sd_10') , r(sd_1)
		mat `sd_11' = nullmat(`sd_11') , r(sd_2)
		
		qui reg `var' `group' if `touse' & `treat'==1 , `options'
		mat `d_1' 	 = nullmat(`d_1')		, r(table)[1, 1]
        mat `d_1_se' = nullmat(`d_1_se')	, r(table)[2, 1]

		/// low intensity group
		qui ttest `var' if `touse' & `treat'==0 , by(`group')
        mat `mu_00' = nullmat(`mu_00') , r(mu_1)
        mat `mu_01' = nullmat(`mu_01') , r(mu_2)
		mat `sd_00' = nullmat(`sd_00') , r(sd_1)
		mat `sd_01' = nullmat(`sd_01') , r(sd_2)
		
		qui reg `var' `group' if `touse' & `treat'==0 , `options'
		mat `d_0' 	 = nullmat(`d_0')		, r(table)[1, 1]
        mat `d_0_se' = nullmat(`d_0_se')	, r(table)[2, 1]
		
		/// diff in diff
		qui reg `var' c.`treat'##c.`group' if `touse', `options'
		mat `dd' 	= nullmat(`dd')		, r(table)[1, 3]
        mat `dd_se' = nullmat(`dd_se')	, r(table)[2, 3]
		mat `dd_p' 	= nullmat(`dd_p')	, r(table)[4, 3]		
    }
	
    foreach mat in mu_10 mu_11 sd_10 sd_11 d_1 d_1_se ///
			 mu_00 mu_01 sd_00 sd_01 d_0 d_0_se ///
			 dd dd_se dd_p {
        mat coln ``mat'' = `varlist'
    }
	
    tempname b V
    mat `b' = `mu_10'*0
    mat `V' = `b''*`b'
	
    eret post `b' `V'
    eret local cmd "sumstats"
	
    foreach mat in mu_10 mu_11 sd_10 sd_11 d_1 d_1_se ///
			 mu_00 mu_01 sd_00 sd_01 d_0 d_0_se ///
			 dd dd_se dd_p {
        eret mat `mat' = ``mat''
    }
end




**** Table
gen inspection = inspectmain
replace inspection = (year>=2015) if !everinspected

eststo sumstats: sumstats comp examinee vacancy $control , treat(everinsp) group(inspection) cl(agcyid)
	
count if everinsp==1 & inspection==1
local n11: di %9.0fc `r(N)'
count if everinsp==1 & inspection==0
local n10: di %9.0fc `r(N)'
count if everinsp==0 & inspection==1
local n01: di %9.0fc `r(N)'
count if everinsp==0 & inspection==0
local n00: di %9.0fc `r(N)'

esttab sumstats using ${tabdir}/table_sumstats.tex , replace ///
	label star(+ .1 * .05 ** .01) noobs nonumber nomtitle nonotes nolz ///
	cells("mu_11(fmt(3)) mu_10(fmt(3)) d_1(fmt(3)) mu_01(fmt(3)) mu_00(fmt(3)) d_0(fmt(3)) dd(star pvalue(dd_p) fmt(3) ) " ///
		  "sd_11(par fmt(3)) sd_10(par fmt(3)) d_1_se(par([ ]) fmt(3)) sd_01(par fmt(3)) sd_00(par fmt(3)) d_0_se(par([ ]) fmt(3)) dd_se(par([ ]) fmt(3))" ) ///
	collab("\makecell{Post \\ Inspection \\ (1)}" "\makecell{Prior \\ Inspection \\ (2)}" "\makecell{Diff. (1)-(2) \\ (3)}" ///
			"\makecell{Post \\ 2015 \\ (4)}" "\makecell{Prior \\ 2015 \\ (5)}" "\makecell{Diff. (4)-(5) \\ (6)}" ///
			"\makecell{DiD (3)-(6) \\ (7)}" ) ///
	refcat(comp "Panel (A): Exam Statistics" exp_unlimited "Panel (B): Covariates" , nolabel) ///
	prehead("\begin{tabular}{l*{7}{c}}" ////
			"\toprule" ///
			"&\multicolumn{3}{c}{Ever Inspected} &\multicolumn{3}{c}{Never Inspected} \\" ///
			"\cmidrule(lr){2-4}\cmidrule(lr){5-7}") ///	
	postfoot("\$N\$ & `n11' & `n10' & &  `n01' & `n00' & & \\" ///
			"\bottomrule" ///
			"\end{tabular}") ///
	booktabs alignment(D{.}{.}{-1}) prefoot("")

			

			
			
			
			
			
			
			
			
*===========================
**# Figure 7: histograms
*===========================
use ${data}/data_for_analysis, clear

**** histogram of comp
sum comp , d
local mean_comp : di %04.3f `r(mean)'
local med_comp : di %04.3f `r(p50)'
local sd_comp : di %04.3f `r(sd)'

hist comp , ///
	xti("AHR") bin(150) fcolor(white) lcolor(black) ///
	scheme(tufte) name(comp , replace) xlab(, format(%9.0fc)) ///
	note("Mean = `mean_comp', Median = `med_comp', SD = `sd_comp'")
	
	gr export ${figdir}/fig_hist_ahr.pdf , replace
	
	
	
sum lncomp , d
local mean_comp : di %04.3f `r(mean)'
local med_comp : di %04.3f `r(p50)'
local sd_comp : di %04.3f `r(sd)'

hist lncomp , ///
	xti("ln(AHR)") bin(100) fcolor(white) lcolor(black) ///
	scheme(tufte) name(lncomp , replace) ///
	note("Mean = `mean_comp', Median = `med_comp', SD = `sd_comp'")
	
	gr export ${figdir}/fig_hist_lnahr.pdf , replace


	
	