cap cd "C:/Users/laiwz/OneDrive - University of Maryland/Research/anticorruption_civil_servant/jle_final/replication"

global data ./data
global figdir ./figure
global tabdir ./table

graph set window fontface "Times New Roman"




*===============================================
**# Figure 1. comp time series: overall
*===============================================
use ${data}/data_for_analysis, clear
collapse (sum) examinee vacancy , by(year)

gen comp = examinee/vacancy
gen lnexaminee = ln(examinee+1)
gen lnvacancy = ln(vacancy+1)

*** add data from media outlets
preserve
clear
input year comp
 2012 53
 2011 59
 2010 59
 2009 58
 2008 46
 2007 42
 2006 48.6
 2005 35
 2004 15
 2003 16
end

replace year = year-1 // time of ncse: e.g., exam for 2012 entry is held in 2011
tempfile earlycomp
save `earlycomp'
restore

append using `earlycomp'
sort year

tw 	///
	(sc comp year, c(l) symbol(o)) , ///
	yti("Applicant-to-Hire Ratio" ) xti("Year") ///
	xlab(2002(1)2017, nogr tlc(black) angle(30)) ylab(20(10)75 , tlc(black)) ///
	xline(2013, lp(--) lc(gray)) text(75 2013 "Anti-Corruption Campaign") ///
	scheme(tufte) leg(off)
		
	gr export ${figdir}/fig_comp_tseries.pdf , replace





*===============================================
**# Figure 8: comp by inspection status
*===============================================
use ${data}/data_for_analysis, clear

collapse (sum) examinee vacancy (mean) comp , by(everinspected year)

sort everinspected year
bysort everinspected (year): gen comp1 = comp if year==2012
bysort everinspected: egen temp = max(comp1)
replace comp1 = temp
drop temp

gen rcomp = comp-comp1

tw 	///
	(sc comp year if everinspected==1 , c(l) lp(solid) symbol(o) ) ///
	(sc comp year if everinspected==0 , c(l) lp(_) symbol(t) ) , ///
	yti("AHR" ) xti( "Year") ///
	xlab(, tlc(black) nogr ) ylab(, tlc(black)) ///
	xline(2013, lp(--) lc(gray)) ///
	scheme(tufte) ///
	leg(order(1 "Ever Inpsected" 2 "Never Inspected") ring(0) pos(2) region(color(none)))

	gr export ${figdir}/fig_rcomp_tseries.pdf , replace

	
	
	

	
	
*===============================================
**# Figure 9: selectivity of bureaucracy
*===============================================
use ${data}/data_for_analysis, clear

collapse (sum) examinee vacancy (mean) educ_vocational educ_college educ_grad exp_unlimited polaff_unlimited , by(everinspected year)
gen comp = examinee/vacancy
gen lnexaminee = ln(examinee+1)
gen lnvacancy = ln(vacancy+1)

// work experience
tw 	///
	(sc exp_unlimited year if everinspected==1 , c(l) lp(solid) symbol(o) ) ///
	(sc exp_unlimited year if everinspected==0 , c(l) lp(_) symbol(t) ) , ///
	yti("Proportion") xti("Year") xline(2013, lp(--) lc(gray)) ///
	xlab(, tlc(black) nogr ) ylab(, tlc(black)) ///
	scheme(tufte) leg(order(1 "Ever Inpsected" 2 "Never Inspected") ) ///
	title("(A) % Experience Unlimited") ///
	name(fig_exp_tseries, replace)

	
// political affiliation
tw 	///
	(sc polaff_unlimited year if everinspected==1 , c(l) lp(solid) symbol(o) ) ///
	(sc polaff_unlimited year if everinspected==0 , c(l) lp(_) symbol(t) ), ///
	yti("Proportion") xti("Year") xline(2013, lp(--) lc(gray)) ///
	xlab(, tlc(black) nogr ) ylab(, tlc(black)) ///
	scheme(tufte) leg(order(1 "Ever Inpsected" 2 "Never Inspected") ) ///
	title("(B) % Political Affiliation Unlimited") ///
	name(fig_polaff_tseries , replace)


// Education
tw 	///
	(sc educ_grad year if everinspected==1 , c(l) lp(solid) symbol(o) ) ///
	(sc educ_grad year if everinspected==0 , c(l) lp(_) symbol(t) ) , ///
	yti("Proportion") xti("Year") xline(2013, lp(--) lc(gray)) ///
	xlab(, tlc(black) nogr ) ylab(, tlc(black)) ///
	scheme(tufte) leg(order(1 "Ever Inpsected" 2 "Never Inspected") ) ///
	title("(C) % Education {&ge} Gradudate Degree") ///
	name(fig_educ_tseries , replace)
	



grc1leg ///
	fig_exp_tseries fig_polaff_tseries fig_educ_tseries  , ///
	legendf(fig_polaff_tseries) ring(0) span graphregion(color(white))
	
gr_edit legend.xoffset = 35
gr_edit legend.yoffset = 25

gr export ${figdir}/fig_require_tseries.pdf , replace
