cap cd "C:/Users/laiwz/OneDrive - University of Maryland/Research/anticorruption_civil_servant/jle_final/replication"

global data ./data
global figdir ./figure
global tabdir ./table

graph set window fontface "Times New Roman"




//=============== Table OA2 ===============//

use ${data}/data_for_analysis, clear
recode yr_inspectagcy (0=.) // never inspected have missing years of inspection

// balance dataset
fillin agcyid year
foreach v of var yr_inspectagcy sysid {
	bysort agcyid: egen temp = max(`v')
	replace `v' = temp if missing(`v')
	drop temp
}

drop system
decode sysid, gen(system)

keep if year==2012
keep if system==agcy
drop year

merge 1:m agcy using ${data}/data_budget, keep(1 3) gen(budgetyes)

tab agcytype, gen(agcytype)
tabstat agcytype? , by(budgetyes) // agencies that I have data are mostly govt agency

tabstat yr_inspectagcy, by(budgetyes)

xtset agcyid year





*============================================
*** Test Balance on Sys Characteristics
*============================================
keep if year==2011 | year==2012
gen sangong = car+recept+abroad
gen fringe = gjj+housing

gen fr_sangong = sangong/tot_funding
gen fr_fringe = fringe/tot_funding

foreach v of var tot_funding sangong fringe fr_sangong fr_fringe {
	forvalues i=2011/2012 {
		gen temp = `v' if year==`i'
		bysort agcy: egen `v'`i' = max(temp)
		drop temp
	}
	
	*if "`v'"!="tot_funding" {
		gen d`v' = `v'2012-`v'2011
	*}
}

keep if year==2012
set seed 2021

global ncse comp exp_unlimited educ_college

foreach v of var $ncse *tot_funding* *sangong* *fringe* {
	egen temp = std(`v')
	replace `v' = temp
	drop temp
}


**** regressions
eststo clear

eststo: reg yr_inspectagcy $ncse , vce(boot)
test $ncse
estadd scalar fpval = `r(p)'

eststo: reg yr_inspectagcy $ncse tot_funding2011 fr_sangong2011 fr_fringe2011 , vce(boot)
test $ncse tot_funding2011 fr_sangong2011 fr_fringe2011 
estadd scalar fpval = `r(p)'

eststo: reg yr_inspectagcy $ncse tot_funding2011 fr_sangong2011 fr_fringe2011 tot_funding2012 fr_sangong2012 fr_fringe2012 , vce(boot)
test $ncse tot_funding2011 fr_sangong2011 fr_fringe2011 tot_funding2012 fr_sangong2012 fr_fringe2012
estadd scalar fpval = `r(p)'

eststo: reg yr_inspectagcy $ncse dtot_funding dfr_sangong dfr_fringe , vce(boot)
test $ncse dtot_funding dfr_sangong dfr_fringe
estadd scalar fpval = `r(p)'


lab var yr_inspectagcy "Year of Inspection"
lab var comp "AHR 2012"
lab var exp_unlimited "\%Exp. unlimited"
lab var educ_college "\%Above college"
lab var tot_funding2011 "Total funding 2011"
lab var tot_funding2012 "Total funding 2012"
lab var fr_sangong2011 "Frac. ETC 2011"
lab var fr_sangong2012 "Frac. ETC 2012"
lab var fr_fringe2011 "Frac. perks 2011"
lab var fr_fringe2012 "Frac. perks 2012"
lab var dtot_funding "\$\Delta\$ Total funding"
lab var dfr_sangong "\$\Delta\$ Frac. ETC"
lab var dfr_fringe "\$\Delta\$ Frac. perks"


esttab using ${tabdir}\table_yrinspection_agcy_corr.tex, replace ///
	b(3) se(3) star(+ 0.1 * 0.05 ** 0.01) ///
	keep($ncse tot_funding2011 fr_sangong2011 fr_fringe2011 tot_funding2012 fr_sangong2012 fr_fringe2012 dtot_funding dfr_sangong dfr_fringe) label ///
	s(fpval N r2, fmt(3 %9.0fc 3) lab("\$F\$-test \$p\$-value" "\$N\$" "\$R^2\$")) ///
	nomtitles nogaps nonotes nolz booktabs alignment(D{.}{.}{-1}) prefoot("")


	

