cap cd "C:/Users/laiwz/OneDrive - University of Maryland/Research/anticorruption_civil_servant/jle_final/replication"

global data ./data
global figdir ./figure
global tabdir ./table

graph set window fontface "Times New Roman"

global control exp_unlimited polaff_unlimited educ_vocational educ_college lngdpp




*=======================================
**# Table OA4: static, twfe
*=======================================
use ${data}/data_for_analysis, clear

eststo clear


*** Regression
forvalues i=2013/2017 {
	gen post`i' = (year==`i')
}

eststo clear

eststo: reghdfe comp inspectmain  , a(agcyid year) cl(agcyid)
estadd local agcyfe "\multicolumn{1}{c}{Yes}", replace
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{No}", replace
sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
estadd scalar ymean = `r(mean)'

eststo: reghdfe comp inspectmain $control  , a(agcyid year) cl(agcyid)
estadd local agcyfe "\multicolumn{1}{c}{Yes}", replace
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{Yes}", replace
sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
estadd scalar ymean = `r(mean)'

dis _b[inspectmain]/`r(mean)'

eststo: reghdfe examinee inspectmain $control  , a(agcyid year) cl(agcyid)
estadd local agcyfe "\multicolumn{1}{c}{Yes}", replace
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{Yes}", replace
sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
estadd scalar ymean = `r(mean)'

dis _b[inspectmain]/`r(mean)'

eststo: reghdfe examinee inspectmain vacancy $control  , a(agcyid year) cl(agcyid)
estadd local agcyfe "\multicolumn{1}{c}{Yes}", replace
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{Yes}", replace
sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
estadd scalar ymean = `r(mean)'

dis _b[inspectmain]/`r(mean)'



*** Make a table
lab var lncomp "ln(AHR)"
lab var comp "AHR"
lab var vacancy "Vacancies"
lab var examinee "Applicants"
lab var lnvacancy "ln(Vacancies)"
lab var lnexaminee "ln(Applicants)"
lab var inspectmain "Inspection"

esttab using ${tabdir}/table_inspection_ahr_twfe.tex, replace ///
	b(3) se(3) star(+ 0.1 * 0.05 ** 0.01) ///
	keep(inspectmain vacancy ) label ///
	s(ymean N_full r2 agcyfe yearfe control, fmt(3 %9.0fc 3 0 0 0) ///
		lab("DV mean, pre-inspection" "\$N\$" "\$R^2\$" "Dept. FE" "Year FE" "Covariates")) ///
	mgroups("DV = AHR" "DV = Applicants", pattern(1 0 1 0 ) prefix(\multicolumn{@span}{c}{) ///
		suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	nogaps nonotes nomti nolz booktabs alignment(D{.}{.}{-1}) prefoot("")


	
	
	
	
	
	
*=======================================
**# Table 2: static, sun & abraham
*=======================================
use ${data}/data_for_analysis, clear


eststo clear

*** col 1
eventstudyinteract comp inspectmain , absorb(agcyid year) cohort(first_inspect) control_cohort(never_inspect) vce(cl agcyid)
	mat b = e(b_iw) , e(b)
	local names: colnames b
	mata: st_matrix("V", blockdiag(st_matrix("e(V_iw)"), st_matrix("e(V)")))
	matrix rownames V = `names'
	matrix colnames V = `names'
	sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
	local ymean = `r(mean)'
	local N = e(N_full)
	local r2 = e(r2)

eststo: ereturn post b V , depn("`e(depvar)'")
estadd scalar N_full = `N'
estadd scalar r2 = `r2'
estadd scalar ymean = `ymean'
estadd local agcyfe "\multicolumn{1}{c}{Yes}", replace
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{No}", replace


*** col 2
eventstudyinteract comp inspectmain , absorb(agcyid year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control}) vce(cl agcyid)
	mat b = e(b_iw) , e(b)
	local names: colnames b
	mata: st_matrix("V", blockdiag(st_matrix("e(V_iw)"), st_matrix("e(V)")))
	matrix rownames V = `names'
	matrix colnames V = `names'
	sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
	local ymean = `r(mean)'
	local N = e(N_full)
	local r2 = e(r2)

eststo: ereturn post b V , depn("`e(depvar)'")
estadd scalar N_full = `N'
estadd scalar r2 = `r2'
estadd scalar ymean = `ymean'
estadd local agcyfe "\multicolumn{1}{c}{Yes}", replace
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{Yes}", replace


*** col 3
eventstudyinteract examinee inspectmain , absorb(agcyid year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control}) vce(cl agcyid)
	mat b = e(b_iw) , e(b)
	local names: colnames b
	mata: st_matrix("V", blockdiag(st_matrix("e(V_iw)"), st_matrix("e(V)")))
	matrix rownames V = `names'
	matrix colnames V = `names'
	sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
	local ymean = `r(mean)'
	local N = e(N_full)
	local r2 = e(r2)

eststo: ereturn post b V , depn("`e(depvar)'")
estadd scalar N_full = `N'
estadd scalar r2 = `r2'
estadd scalar ymean = `ymean'
estadd local agcyfe "\multicolumn{1}{c}{Yes}", replace
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{Yes}", replace


*** col 4
eventstudyinteract examinee inspectmain , absorb(agcyid year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control} vacancy) vce(cl agcyid)
	mat b = e(b_iw) , e(b)
	local names: colnames b
	mata: st_matrix("V", blockdiag(st_matrix("e(V_iw)"), st_matrix("e(V)")))
	matrix rownames V = `names'
	matrix colnames V = `names'
	sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
	local ymean = `r(mean)'
	local N = e(N_full)
	local r2 = e(r2)

eststo: ereturn post b V , depn("`e(depvar)'")
estadd scalar N_full = `N'
estadd scalar r2 = `r2'
estadd scalar ymean = `ymean'
estadd local agcyfe "\multicolumn{1}{c}{Yes}", replace
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{Yes}", replace


*** make a table
lab var lncomp "ln(AHR)"
lab var comp "AHR"
lab var vacancy "Vacancies"
lab var examinee "Applicants"
lab var lnvacancy "ln(Vacancies)"
lab var lnexaminee "ln(Applicants)"
lab var inspectmain "Inspection"


esttab using ${tabdir}/table_inspection_ahr.tex, replace ///
	b(3) se(3) star(+ 0.1 * 0.05 ** 0.01) ///
	keep(inspectmain vacancy ) label ///
	s(ymean N_full r2 agcyfe yearfe control, fmt(3 %9.0fc 3 0 0 0) ///
		lab("DV mean, pre-inspection" "\$N\$" "\$R^2\$" "Dept. FE" "Year FE" "Covariates")) ///
	mgroups("DV = AHR" "DV = Applicants", pattern(1 0 1 0 ) prefix(\multicolumn{@span}{c}{) ///
		suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	nogaps nonotes nomti nolz booktabs alignment(D{.}{.}{-1}) prefoot("")

	
	
	
	
	
	
*===============================================
**# Figure 10 event study, sun & abraham
*==============================================

**## regression
use ${data}/data_for_analysis, clear

gen gap = year-yr_inspectagcy
tab gap

forvalues i=1/5 {
	local j = `i'-6
	local k = abs(`j')
	gen d_`k' = (gap==`j')*(yr_inspectagcy>0)*main
}

forvalues i=0/4 {
	gen d`i' = (gap==`i')*(yr_inspectagcy>0)*main
}



*** main sample
eventstudyinteract comp d_5-d_2 d0-d4 d_1 , absorb(agcyid year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control}) vce(cl agcyid)
mat A = r(table)
mat A = A'
xsvmat A , names(matcol) saving(${data}/eventstudy_sumabraham , replace)


*** drop 2016
eventstudyinteract comp d_5-d_2 d0-d4 d_1 if yr_inspectmain!=2016 , absorb(agcyid year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control}) vce(cl agcyid)
mat A = r(table)
mat A = A'
xsvmat A , names(matcol) saving(${data}/eventstudy_drop2016_sumabraham , replace)


*** PSM
use ${data}/data_psm , clear
gen gap = year-yr_inspectagcy
tab gap

forvalues i=1/5 {
	local j = `i'-6
	local k = abs(`j')
	gen d_`k' = (gap==`j')*(yr_inspectagcy>0)*main
}

forvalues i=0/4 {
	gen d`i' = (gap==`i')*(yr_inspectagcy>0)*main
}

gen first_inspect = yr_inspectagcy if everinspected
gen never_inspect = !everinspected //(first_inspect==.)

eventstudyinteract comp d_5-d_2 d0-d4 d_1 , absorb(i.agcyid i.year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control}) vce(cl agcyid)
mat A = r(table)
mat A = A'
xsvmat A , names(matcol) saving(${data}/eventstudy_sumabraham_psm , replace)





**## plotting
local i = 1

foreach f in eventstudy_sumabraham eventstudy_drop2016_sumabraham eventstudy_sumabraham_psm {

use ${data}/`f', clear
renvars , subst("A" "")
gen min95 = b-1.96*se
gen max95 = b+1.96*se
gen x = _n-6 if _n<=4
replace x = _n-5 if _n>4
replace x = -1 in L
sort x
gen z = `i'
save ${data}/`f' , replace

local i = `i'+1
}



/// results of orig ES
openall eventstudy_sumabraham eventstudy_drop2016_sumabraham eventstudy_sumabraham_psm , directory(${data})
replace x = x-.2 if z==1
replace x = x+.2 if z==3

tw ///
	(rcap min95 max95 x if z==1 , ) ///
	(sc b x if z==1 , msymbol(O) lp(solid) c(l) ) ///
	(rcap min95 max95 x if z==2 , lp(_) lcolor(gs5) ) ///
	(sc b x if z==2 , msymbol(T) lcolor(gs5) lp(--) mcolor(gs5) c(l) ) ///
	(rcap min95 max95 x if z==3 , lp(-.) lcolor(gs10) ) ///
	(sc b x if z==3 , msymbol(D) lcolor(gs10) lp(-.) mcolor(gs10) c(l) ) , ///
	xline(-1, lp(-) lc(gray)) yline(0, lp(-) lc(gray)) ///
	xti( "Year Relative to Inspection") xlab(-5(1)4 , nogr) xsc(range(-6 5)) ///
	yti("Effect of Inspections on AHR" ) ///
	text(-190 -3 "Prior Inspection" -190 1.5 "Post Inspection") ///
	leg(order(2 "Full Sample" 4 "w/o 2016 Inspected"  6 "PSM Sample" ) pos(1) ring(0) region(color(none))) scheme(tufte)

	gr export ${figdir}/fig_eventstudy.pdf, replace


	
*** clean intermediate files
foreach f in "eventstudy_sumabraham" "eventstudy_drop2016_sumabraham" "eventstudy_sumabraham_psm" {
	erase ${data}/`f'.dta
}