//============== Robustness Checks ================//
cap cd "C:/Users/laiwz/OneDrive - University of Maryland/Research/anticorruption_civil_servant/jle_final/replication"

global data ./data
global figdir ./figure
global tabdir ./table

graph set window fontface "Times New Roman"


global control exp_unlimited polaff_unlimited educ_vocational educ_college lngdpp



*===============================
**# Table 3 Regression to the mean
*===============================
use ${data}/data_for_analysis, clear

gen inspectbranch = inspectagcy*(main==0)
gen gap = year-yr_inspectagcy
tab gap

forvalues i=1/5 {
	local j = `i'-6
	local k = abs(`j')
	gen d_`k' = (gap==`j')*(yr_inspectagcy>0)*main
}

forvalues i=0/4 {
	gen d`i' = (gap==`i')*(yr_inspectagcy>0)*main
}


eststo clear


**## Control trends
global control_int exp_unlimited polaff_unlimited educ_vocational educ_college lngdpp

foreach v in $control {
	global control_int ${control_int} c.`v'#i.year
}

eventstudyinteract comp inspectmain , absorb(agcyid year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control_int}) vce(cl agcyid)
	mat b = e(b_iw) , e(b)
	local names: colnames b
	mata: st_matrix("V", blockdiag(st_matrix("e(V_iw)"), st_matrix("e(V)")))
	matrix rownames V = `names'
	matrix colnames V = `names'
	sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
	local ymean = `r(mean)'
	local N = e(N_full)
	local r2 = e(r2)

eststo: ereturn post b V , depname("`e(depvar)'")
estadd scalar N_full = `N'
estadd scalar r2 = `r2'
estadd scalar ymean = `ymean'
estadd local agcyfe "\multicolumn{1}{c}{Yes}", replace
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local provyear "\multicolumn{1}{c}{No}", replace
estadd local control "\multicolumn{1}{c}{No}", replace
estadd local control_int "\multicolumn{1}{c}{Yes}", replace
estadd local treated "\multicolumn{1}{c}{Full}"
estadd local untreated "\multicolumn{1}{c}{Full}"


eventstudyinteract comp inspectmain , absorb(agcyid provcd#year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control}) vce(cl agcyid)
	mat b = e(b_iw) , e(b)
	local names: colnames b
	mata: st_matrix("V", blockdiag(st_matrix("e(V_iw)"), st_matrix("e(V)")))
	matrix rownames V = `names'
	matrix colnames V = `names'
	sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
	local ymean = `r(mean)'
	local N = e(N_full)
	local r2 = e(r2)

eststo: ereturn post b V , depname("`e(depvar)'")
estadd scalar N_full = `N'
estadd scalar r2 = `r2'
estadd scalar ymean = `ymean'
estadd local agcyfe "\multicolumn{1}{c}{Yes}", replace
estadd local yearfe "\multicolumn{1}{c}{No}", replace
estadd local provyear "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{Yes}", replace
estadd local control_int "\multicolumn{1}{c}{No}", replace
estadd local treated "\multicolumn{1}{c}{Full}"
estadd local untreated "\multicolumn{1}{c}{Full}"


eventstudyinteract comp inspectmain , absorb(agcyid provcd#year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control_int}) vce(cl agcyid)
	mat b = e(b_iw) , e(b)
	local names: colnames b
	mata: st_matrix("V", blockdiag(st_matrix("e(V_iw)"), st_matrix("e(V)")))
	matrix rownames V = `names'
	matrix colnames V = `names'
	sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
	local ymean = `r(mean)'
	local N = e(N_full)
	local r2 = e(r2)

eststo: ereturn post b V , depname("`e(depvar)'")
estadd scalar N_full = `N'
estadd scalar r2 = `r2'
estadd scalar ymean = `ymean'
estadd local agcyfe "\multicolumn{1}{c}{Yes}", replace
estadd local yearfe "\multicolumn{1}{c}{No}", replace
estadd local provyear "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{No}", replace
estadd local control_int "\multicolumn{1}{c}{Yes}", replace
estadd local treated "\multicolumn{1}{c}{Full}"
estadd local untreated "\multicolumn{1}{c}{Full}"




**## Sample where unparallel trends are least likely
/*
For ever treated, drop units with high pre-treatment y, which are more likely to go down
For never treated, drop units w/ low pre-2015 y, which are likely to go up afterwards
These constitute a powerful test for true treatment effect
*/

gen temp = !inspectmain*comp if everinspected
replace temp = (year<2015)*comp if !everinspected
bysort agcyid: egen precomp = mean(temp)
drop temp

*eststo clear

sum precomp if !everinspected , d
local cut0 = `r(p10)'
sum precomp if everinspected , d
local cut1 = `r(p90)'

eventstudyinteract comp inspectmain if (!everinspected & precomp>`cut0' ) | (everinspected & precomp<`cut1') , absorb(agcyid year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control}) vce(cl agcyid)
	mat b = e(b_iw) , e(b)
	local names: colnames b
	mata: st_matrix("V", blockdiag(st_matrix("e(V_iw)"), st_matrix("e(V)")))
	matrix rownames V = `names'
	matrix colnames V = `names'
	sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
	local ymean = `r(mean)'
	local N = e(N_full)
	local r2 = e(r2)

eststo: ereturn post b V , depname("`e(depvar)'")
estadd scalar N_full = `N'
estadd scalar r2 = `r2'
estadd scalar ymean = `ymean'
estadd local agcyfe "\multicolumn{1}{c}{Yes}", replace
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local provyear "\multicolumn{1}{c}{No}", replace
estadd local control "\multicolumn{1}{c}{Yes}", replace
estadd local control_int "\multicolumn{1}{c}{No}", replace
estadd local treated "\multicolumn{1}{c}{Pre-Inspection AHR < 90th pctl}"
estadd local untreated "\multicolumn{1}{c}{Pre-2015 AHR > 10th pctl}"



**## PSM
use ${data}/data_psm , clear
gen first_inspect = yr_inspectagcy if everinspected
gen never_inspect = !everinspected //(first_inspect==.)


eventstudyinteract comp inspectmain [aw=wght] , absorb(agcyid year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control}) vce(cl agcyid)
	mat b = e(b_iw) , e(b)
	local names: colnames b
	mata: st_matrix("V", blockdiag(st_matrix("e(V_iw)"), st_matrix("e(V)")))
	matrix rownames V = `names'
	matrix colnames V = `names'
	sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
	local ymean = `r(mean)'
	local N = e(N_full)
	local r2 = e(r2)

eststo: ereturn post b V , depname("`e(depvar)'")
estadd scalar N_full = `N'
estadd scalar r2 = `r2'
estadd scalar ymean = `ymean'
estadd local agcyfe "\multicolumn{1}{c}{Yes}", replace
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local provyear "\multicolumn{1}{c}{No}", replace
estadd local control "\multicolumn{1}{c}{Yes}", replace
estadd local control_int "\multicolumn{1}{c}{No}", replace
estadd local treated "\multicolumn{1}{c}{Full}"
estadd local untreated "\multicolumn{1}{c}{PSM Matched}"


**** Make a table
lab var comp "AHR"
lab var inspectmain "Inspection"

esttab using ${tabdir}/table_reg2mean.tex, replace ///
	b(3) se(3) star(+ 0.1 * 0.05 ** 0.01) ///
	keep(inspectmain ) label ///
	s(N_full r2 treated untreated agcyfe yearfe control control_int provyear, fmt(%9.0fc 3 0 0 0 0 0 0 0) ///
		lab("\$N\$" "\$R^2\$" "Treated" "Untreated" "Dept. FE" "Year FE" "Covariates" "Covariates \$\times\$ Year FE" "Province \$\times\$ Year FE")) ///
	mgroups("Controls for Trends" "MR-Least-Likely Subsample", pattern(1 0 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	nogaps nonotes nolz booktabs alignment(D{.}{.}{-1}) prefoot("")



	
	
	
	
	
*=========================
**# Table OA1: Pretrends
*=========================
use ${data}/data_for_analysis, clear
xtset agcyid year
sort agcyid year

bysort agcyid (year): gen dcomp = D.comp //-comp[_n-1] //if year<yr_inspectagcy


/// Regressions
eststo clear

eststo: reghdfe dcomp c.everinspected#i.year $control if (yr_inspectmain==0 | yr_inspectmain==2014) & year<2014 , a(year) cl(agcyid)
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{Yes}", replace

eststo: reghdfe dcomp c.everinspected#i.year $control if (yr_inspectmain==0 | yr_inspectmain==2015) & year<2015 , a(year) cl(agcyid)
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{Yes}", replace

eststo: reghdfe dcomp c.everinspected#i.year $control if (yr_inspectmain==0 | yr_inspectmain==2016) & year<2016 , a(year) cl(agcyid)
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{Yes}", replace

eststo: reghdfe dcomp c.everinspected#i.year $control if (yr_inspectmain==0 | yr_inspectmain==2017) & year<2017 , a(year) cl(agcyid)
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{Yes}", replace

lab var everinspected "Ever Inspected"
lab var year "Year"

esttab using ${tabdir}/table_pretrends.tex, replace ///
	b(3) se(3) star(+ 0.1 * 0.05 ** 0.01) ///
	drop($control _cons) label ///
	s(N_full r2 yearfe control, fmt(%9.0fc 3 0 0) lab("\$N\$" "\$R^2\$" "Year FE" "Covariates")) ///
	mtitles("2014 vs. Never" "2015 vs. Never" "2016 vs. Never" "2017 vs. Never") nogaps nonotes ///
	interact(" \$\times\$ ") nolz booktabs alignment(D{.}{.}{-1}) prefoot("")






*=======================================
**# Table 4 Spillover: Cross Section
*=======================================
use ${data}/data_for_analysis, clear

gen inspectbranch = inspectagcy*(main==0)
recode yr_inspectagcy (.=0)

eststo clear



eventstudyinteract comp inspectmain , absorb(agcyid year) cohort(first_inspect) control_cohort(never_inspect) covariates(inspectbranch ${control}) vce(cl agcyid)
	mat b = e(b_iw) , e(b)
	local names: colnames b
	mata: st_matrix("V", blockdiag(st_matrix("e(V_iw)"), st_matrix("e(V)")))
	matrix rownames V = `names'
	matrix colnames V = `names'
	sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
	local ymean = `r(mean)'
	local N = e(N_full)
	local r2 = e(r2)
	
eststo: ereturn post b V , depname("`e(depvar)'")
estadd scalar N_full = `N'
estadd scalar r2 = `r2'
estadd scalar ymean = `ymean'
estadd local samp "\multicolumn{1}{c}{Dept.}" , replace
estadd local agcyfe "\multicolumn{1}{c}{Yes}" , replace
estadd local yearfe "\multicolumn{1}{c}{Yes}" , replace
estadd local covar "\multicolumn{1}{c}{Yes}" , replace
estadd local provfe "\multicolumn{1}{c}{No}" , replace
estadd local sysfe "\multicolumn{1}{c}{No}" , replace




eventstudyinteract comp inspectmain , absorb(provcd sysid year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control}) vce(cl agcyid)
	mat b = e(b_iw) , e(b)
	local names: colnames b
	mata: st_matrix("V", blockdiag(st_matrix("e(V_iw)"), st_matrix("e(V)")))
	matrix rownames V = `names'
	matrix colnames V = `names'
	sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
	local ymean = `r(mean)'
	local N = e(N_full)
	local r2 = e(r2)
	
eststo: ereturn post b V , depname("`e(depvar)'")
estadd scalar N_full = `N'
estadd scalar r2 = `r2'
estadd scalar ymean = `ymean'
estadd local samp "\multicolumn{1}{c}{Dept.}" , replace
estadd local agcyfe "\multicolumn{1}{c}{No}" , replace
estadd local yearfe "\multicolumn{1}{c}{Yes}" , replace
estadd local covar "\multicolumn{1}{c}{Yes}" , replace
estadd local provfe "\multicolumn{1}{c}{Yes}" , replace
estadd local sysfe "\multicolumn{1}{c}{Yes}" , replace



eventstudyinteract comp inspectmain , absorb(provcd sysid year) cohort(first_inspect) control_cohort(never_inspect) covariates(inspectbranch ${control}) vce(cl agcyid)
	mat b = e(b_iw) , e(b)
	local names: colnames b
	mata: st_matrix("V", blockdiag(st_matrix("e(V_iw)"), st_matrix("e(V)")))
	matrix rownames V = `names'
	matrix colnames V = `names'
	sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
	local ymean = `r(mean)'
	local N = e(N_full)
	local r2 = e(r2)
	
eststo: ereturn post b V , depname("`e(depvar)'")
estadd scalar N_full = `N'
estadd scalar r2 = `r2'
estadd scalar ymean = `ymean'
estadd local samp "\multicolumn{1}{c}{Dept.}" , replace
estadd local agcyfe "\multicolumn{1}{c}{No}" , replace
estadd local yearfe "\multicolumn{1}{c}{Yes}" , replace
estadd local covar "\multicolumn{1}{c}{Yes}" , replace
estadd local provfe "\multicolumn{1}{c}{Yes}" , replace
estadd local sysfe "\multicolumn{1}{c}{Yes}" , replace



// collapse data to system level
preserve

collapse (rawsum) examinee vacancy (max) yr_inspectagcy (mean) $control [weight=vacancy] , by(system sysid year)

gen comp = examinee/vacancy
gen lncomp = ln(1+comp)
recode yr_inspectagcy (.=0)
gen inspectmain = (year>=yr_inspectagcy)

bysort sysid: egen everinspected = max(inspectmain)
gen first_inspect = yr_inspectagcy if everinspected
gen never_inspect = !everinspected //(first_inspect==.)

eventstudyinteract comp inspectmain , absorb(sysid year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control}) vce(cl sysid)
	mat b = e(b_iw) , e(b)
	local names: colnames b
	mata: st_matrix("V", blockdiag(st_matrix("e(V_iw)"), st_matrix("e(V)")))
	matrix rownames V = `names'
	matrix colnames V = `names'
	sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
	local ymean = `r(mean)'
	local N = e(N_full)
	local r2 = e(r2)
	
eststo: ereturn post b V , depname("`e(depvar)'")
estadd scalar N_full = `N'
estadd scalar r2 = `r2'
estadd scalar ymean = `ymean'
estadd local samp "\multicolumn{1}{c}{Branch}" , replace
estadd local agcyfe "\multicolumn{1}{c}{No}" , replace
estadd local yearfe "\multicolumn{1}{c}{Yes}" , replace
estadd local covar "\multicolumn{1}{c}{Yes}" , replace
estadd local provfe "\multicolumn{1}{c}{No}" , replace
estadd local sysfe "\multicolumn{1}{c}{Yes}" , replace


restore


*** make a table
lab var comp "AHR"
lab var examinee "Examinee"
lab var lnexaminee "ln(Examinee)"
lab var inspectmain "Insp. on leading dept."
lab var inspectbranch "(Counterfactual) insp. on affiliated dept."

esttab using ${tabdir}/table_robustness_spillover.tex , replace ///
	b(3) se(3) star(+ .1 * .05 ** .01) ///
	keep(inspectmain inspectbranch) label ///
	s(N_full r2 samp agcyfe yearfe provfe sysfe covar , lab("\$N\$" "\$R^2\$" "Sample Level" "Dept. FE" "Year FE" "Province FE" "Branch FE" "Covariates") fmt(%9.0fc 3 0 0 0 0 0 0)) ///
	nogaps nonotes nolz booktabs alignment(D{.}{.}{-1}) prefoot("")



	
	
	
	
	


*=======================================
**# Table OA6: AET
*=======================================
use ${data}/data_for_analysis, clear


eststo clear

cap drop predicted_inspectmain resid
reghdfe inspectmain $control, a(agcyid year) cl(agcyid) resid(resid)
gen predicted_inspectmain = inspectmain - resid

eststo: reghdfe comp predicted_inspectmain , a(agcyid year) cl(agcyid)

lab var predicted_inspectmain "Pred. inspection"
esttab using ${tabdir}\table_robustness_AET.tex , replace ///
	b(3) se(3) star(+ .1 * .05 ** .01) ///
	keep(predicted_inspectmain) label ///
	s(N_full r2, lab("\$N\$" "\$R^2\$") fmt(%9.0fc 3)) ///
	nogaps nomtitles nonotes nolz booktabs alignment(D{.}{.}{-1}) prefoot("")
	
	
	
	
	
*=======================================
**# Figure OA6: Oster's delta
*=======================================
use ${data}/data_for_analysis, clear

tab agcyid , gen(_agcyid)
tab year , gen(_year)



**** Rmax = 1.3*R
/*
global control exp_unlimited polaff_unlimited educ_vocational educ_college

reg comp $control _agcyid* _year* inspectmain
local c = 1.3*e(r2)
display `c'

qui psacalc delta inspectmain, rmax(`c') mcontrol(_agcyid1 _agcyid2 _agcyid3 _agcyid4 _agcyid5 _agcyid6 _agcyid7 _agcyid8 _agcyid9 _agcyid10 _agcyid11 _agcyid12 _agcyid13 _agcyid14 _agcyid15 _agcyid16 _agcyid17 _agcyid18 _agcyid19 _agcyid20 _agcyid21 _agcyid22 _agcyid23 _agcyid24 _agcyid25 _agcyid26 _agcyid27 _agcyid28 _agcyid29 _agcyid30 _agcyid31 _agcyid32 _agcyid33 _agcyid34 _agcyid35 _agcyid36 _agcyid37 _agcyid38 _agcyid39 _agcyid40 _agcyid41 _agcyid42 _agcyid43 _agcyid44 _agcyid45 _agcyid46 _agcyid47 _agcyid48 _agcyid49 _agcyid50 _agcyid51 _agcyid52 _agcyid53 _agcyid54 _agcyid55 _agcyid56 _agcyid57 _agcyid58 _agcyid59 _agcyid60 _agcyid61 _agcyid62 _agcyid63 _agcyid64 _agcyid65 _agcyid66 _agcyid67 _agcyid68 _agcyid69 _agcyid70 _agcyid71 _agcyid72 _agcyid73 _agcyid74 _agcyid75 _agcyid76 _agcyid77 _agcyid78 _agcyid79 _agcyid80 _agcyid81 _agcyid82 _agcyid83 _agcyid84 _agcyid85 _agcyid86 _agcyid87 _agcyid88 _agcyid89 _agcyid90 _agcyid91 _agcyid92 _agcyid93 _agcyid94 _agcyid95 _agcyid96 _agcyid97 _agcyid98 _agcyid99 _agcyid100 _agcyid101 _agcyid102 _agcyid103 _agcyid104 _agcyid105 _agcyid106 _agcyid107 _agcyid108 _agcyid109 _agcyid110 _agcyid111 _agcyid112 _agcyid113 _agcyid114 _agcyid115 _agcyid116 _agcyid117 _agcyid118 _agcyid119 _agcyid120 _agcyid121 _agcyid122 _agcyid123 _agcyid124 _agcyid125 _agcyid126 _agcyid127 _agcyid128 _agcyid129 _agcyid130 _agcyid131 _agcyid132 _agcyid133 _agcyid134 _agcyid135 _agcyid136 _agcyid137 _agcyid138 _agcyid139 _agcyid140 _agcyid141 _agcyid142 _agcyid143 _agcyid144 _agcyid145 _agcyid146 _agcyid147 _agcyid148 _agcyid149 _agcyid150 _agcyid151 _agcyid152 _agcyid153 _agcyid154 _agcyid155 _agcyid156 _agcyid157 _agcyid158 _agcyid159 _agcyid160 _agcyid161 _agcyid162 _agcyid163 _agcyid164 _agcyid165 _agcyid166 _agcyid167 _agcyid168 _agcyid169 _agcyid170 _agcyid171 _agcyid172 _agcyid173 _agcyid174 _agcyid175 _agcyid176 _agcyid177 _agcyid178 _agcyid179 _agcyid180 _agcyid181 _agcyid182 _agcyid183 _agcyid184 _agcyid185 _agcyid186 _agcyid187 _agcyid188 _agcyid189 _agcyid190 _agcyid191 _agcyid192 _agcyid193 _agcyid194 _agcyid195 _agcyid196 _agcyid197 _agcyid198 _agcyid199 _agcyid200 _agcyid201 _agcyid202 _agcyid203 _agcyid204 _agcyid205 _agcyid206 _agcyid207 _agcyid208 _agcyid209 _agcyid210 _agcyid211 _agcyid212 _agcyid213 _agcyid214 _agcyid215 _agcyid216 _agcyid217 _agcyid218 _agcyid219 _agcyid220 _agcyid221 _agcyid222 _agcyid223 _agcyid224 _agcyid225 _agcyid226 _agcyid227 _agcyid228 _agcyid229 _agcyid230 _agcyid231 _agcyid232 _agcyid233 _agcyid234 _agcyid235 _agcyid236 _agcyid237 _agcyid238 _agcyid239 _agcyid240 _agcyid241 _agcyid242 _agcyid243 _agcyid244 _agcyid245 _agcyid246 _agcyid247 _agcyid248 _agcyid249 _agcyid250 _agcyid251 _agcyid252 _agcyid253 _agcyid254 _agcyid255 _agcyid256 _agcyid257 _agcyid258 _agcyid259 _agcyid260 _agcyid261 _agcyid262 _agcyid263 _agcyid264 _agcyid265 _agcyid266 _agcyid267 _agcyid268 _agcyid269 _agcyid270 _agcyid271 _agcyid272 _agcyid273 _agcyid274 _agcyid275 _agcyid276 _agcyid277 _agcyid278 _agcyid279 _agcyid280 _agcyid281 _agcyid282 _agcyid283 _agcyid284 _agcyid285 _agcyid286 _agcyid287 _agcyid288 _agcyid289 _agcyid290 _agcyid291 _agcyid292 _agcyid293 _agcyid294 _agcyid295 _agcyid296 _agcyid297 _agcyid298 _agcyid299 _agcyid300 _agcyid301 _agcyid302 _agcyid303 _agcyid304 _agcyid305 _agcyid306 _agcyid307 _agcyid308 _agcyid309 _agcyid310 _agcyid311 _agcyid312 _agcyid313 _agcyid314 _agcyid315 _agcyid316 _agcyid317 _agcyid318 _agcyid319 _agcyid320 _agcyid321 _agcyid322 _agcyid323 _agcyid324 _agcyid325 _agcyid326 _agcyid327 _agcyid328 _agcyid329 _agcyid330 _agcyid331 _agcyid332 _agcyid333 _agcyid334 _agcyid335 _agcyid336 _agcyid337 _agcyid338 _agcyid339 _agcyid340 _agcyid341 _agcyid342 _agcyid343 _agcyid344 _agcyid345 _agcyid346 _agcyid347 _agcyid348 _agcyid349 _agcyid350 _agcyid351 _agcyid352 _agcyid353 _agcyid354 _agcyid355 _agcyid356 _agcyid357 _agcyid358 _agcyid359 _agcyid360 _agcyid361 _agcyid362 _agcyid363 _agcyid364 _agcyid365 _agcyid366 _agcyid367 _agcyid368 _agcyid369 _agcyid370 _agcyid371 _agcyid372 _agcyid373 _agcyid374 _agcyid375 _agcyid376 _agcyid377 _agcyid378 _agcyid379 _agcyid380 _agcyid381 _agcyid382 _agcyid383 _agcyid384 _agcyid385 _agcyid386 _agcyid387 _agcyid388 _agcyid389 _agcyid390 _agcyid391 _agcyid392 _agcyid393 _agcyid394 _agcyid395 _agcyid396 _agcyid397 _agcyid398 _agcyid399 _agcyid400 _agcyid401 _agcyid402 _agcyid403 _agcyid404 _agcyid405 _agcyid406 _agcyid407 _agcyid408 _agcyid409 _agcyid410 _agcyid411 _agcyid412 _agcyid413 _agcyid414 _agcyid415 _agcyid416 _agcyid417 _agcyid418 _agcyid419 _agcyid420 _agcyid421 _agcyid422 _agcyid423 _agcyid424 _agcyid425 _agcyid426 _agcyid427 _agcyid428 _agcyid429 _agcyid430 _agcyid431 _agcyid432 _agcyid433 _agcyid434 _agcyid435 _agcyid436 _agcyid437 _agcyid438 _agcyid439 _agcyid440 _agcyid441 _agcyid442 _agcyid443 _agcyid444 _agcyid445 _agcyid446 _agcyid447 _agcyid448 _agcyid449 _agcyid450 _agcyid451 _agcyid452 _agcyid453 _agcyid454 _agcyid455 _agcyid456 _agcyid457 _agcyid458 _agcyid459 _agcyid460 _agcyid461 _agcyid462 _agcyid463 _agcyid464 _agcyid465 _agcyid466 _agcyid467 _agcyid468 _agcyid469 _agcyid470 _agcyid471 _agcyid472 _agcyid473 _agcyid474 _agcyid475 _agcyid476 _agcyid477 _agcyid478 _agcyid479 _agcyid480 _agcyid481 _agcyid482 _agcyid483 _agcyid484 _agcyid485 _agcyid486 _agcyid487 _agcyid488 _agcyid489 _agcyid490 _agcyid491 _agcyid492 _agcyid493 _agcyid494 _agcyid495 _agcyid496 _agcyid497 _agcyid498 _agcyid499 _agcyid500 _agcyid501 _agcyid502 _agcyid503 _agcyid504 _agcyid505 _agcyid506 _agcyid507 _agcyid508 _agcyid509 _agcyid510 _agcyid511 _agcyid512 _agcyid513 _agcyid514 _agcyid515 _agcyid516 _agcyid517 _agcyid518 _agcyid519 _agcyid520 _agcyid521 _agcyid522 _agcyid523 _agcyid524 _agcyid525 _agcyid526 _agcyid527 _agcyid528 _agcyid529 _agcyid530 _agcyid531 _agcyid532 _agcyid533 _agcyid534 _agcyid535 _agcyid536 _agcyid537 _agcyid538 _agcyid539 _agcyid540 _agcyid541 _agcyid542 _agcyid543 _agcyid544 _agcyid545 _agcyid546 _agcyid547 _agcyid548 _agcyid549 _agcyid550 _agcyid551 _agcyid552 _agcyid553 _agcyid554 _agcyid555 _agcyid556 _agcyid557 _agcyid558 _agcyid559 _agcyid560 _agcyid561 _agcyid562 _agcyid563 _agcyid564 _agcyid565 _agcyid566 _agcyid567 _agcyid568 _agcyid569 _agcyid570 _agcyid571 _agcyid572 _agcyid573 _agcyid574 _agcyid575 _agcyid576 _agcyid577 _agcyid578 _agcyid579 _agcyid580 _agcyid581 _agcyid582 _agcyid583 _agcyid584 _agcyid585 _agcyid586 _agcyid587 _agcyid588 _agcyid589 _agcyid590 _agcyid591 _agcyid592 _agcyid593 _agcyid594 _agcyid595 _agcyid596 _agcyid597 _agcyid598 _agcyid599 _agcyid600 _agcyid601 _agcyid602 _agcyid603 _agcyid604 _agcyid605 _agcyid606 _agcyid607 _agcyid608 _agcyid609 _agcyid610 _agcyid611 _agcyid612 _agcyid613 _agcyid614 _agcyid615 _agcyid616 _agcyid617 _agcyid618 _agcyid619 _agcyid620 _agcyid621 _agcyid622 _agcyid623 _agcyid624 _agcyid625 _agcyid626 _agcyid627 _agcyid628 _agcyid629 _agcyid630 _agcyid631 _agcyid632 _agcyid633 _agcyid634 _agcyid635 _agcyid636 _agcyid637 _agcyid638 _agcyid639 _agcyid640 _agcyid641 _agcyid642 _agcyid643 _agcyid644 _agcyid645 _agcyid646 _agcyid647 _agcyid648 _agcyid649 _agcyid650 _agcyid651 _agcyid652 _agcyid653 _agcyid654 _agcyid655 _agcyid656 _agcyid657 _agcyid658 _agcyid659 _agcyid660 _agcyid661 _agcyid662 _agcyid663 _agcyid664 _agcyid665 _agcyid666 _agcyid667 _agcyid668 _agcyid669 _agcyid670 _agcyid671 _agcyid672 _agcyid673 _agcyid674 _agcyid675 _agcyid676 _agcyid677 _agcyid678 _agcyid679 _agcyid680 _agcyid681 _agcyid682 _agcyid683 _agcyid684 _agcyid685 _agcyid686 _agcyid687 _agcyid688 _agcyid689 _agcyid690 _agcyid691 _agcyid692 _agcyid693 _agcyid694 _agcyid695 _agcyid696 _agcyid697 _agcyid698 _agcyid699 _agcyid700 _agcyid701 _agcyid702 _agcyid703 _agcyid704 _agcyid705 _agcyid706 _agcyid707 _agcyid708 _agcyid709 _agcyid710 _agcyid711 _agcyid712 _agcyid713 _agcyid714 _agcyid715 _agcyid716 _agcyid717 _year1 _year2 _year3 _year4 _year5 _year6)

dis `r(delta)'

mat A = [. , .]
mat A = [`c' , `r(delta)']



**** delta as a function of Rmax
foreach c of num .65 .7 .75 .8 .9 .95 1 {
	qui reg comp $control _agcyid* _year* inspectmain
	qui psacalc delta inspectmain, rmax(`c') mcontrol(_agcyid1 _agcyid2 _agcyid3 _agcyid4 _agcyid5 _agcyid6 _agcyid7 _agcyid8 _agcyid9 _agcyid10 _agcyid11 _agcyid12 _agcyid13 _agcyid14 _agcyid15 _agcyid16 _agcyid17 _agcyid18 _agcyid19 _agcyid20 _agcyid21 _agcyid22 _agcyid23 _agcyid24 _agcyid25 _agcyid26 _agcyid27 _agcyid28 _agcyid29 _agcyid30 _agcyid31 _agcyid32 _agcyid33 _agcyid34 _agcyid35 _agcyid36 _agcyid37 _agcyid38 _agcyid39 _agcyid40 _agcyid41 _agcyid42 _agcyid43 _agcyid44 _agcyid45 _agcyid46 _agcyid47 _agcyid48 _agcyid49 _agcyid50 _agcyid51 _agcyid52 _agcyid53 _agcyid54 _agcyid55 _agcyid56 _agcyid57 _agcyid58 _agcyid59 _agcyid60 _agcyid61 _agcyid62 _agcyid63 _agcyid64 _agcyid65 _agcyid66 _agcyid67 _agcyid68 _agcyid69 _agcyid70 _agcyid71 _agcyid72 _agcyid73 _agcyid74 _agcyid75 _agcyid76 _agcyid77 _agcyid78 _agcyid79 _agcyid80 _agcyid81 _agcyid82 _agcyid83 _agcyid84 _agcyid85 _agcyid86 _agcyid87 _agcyid88 _agcyid89 _agcyid90 _agcyid91 _agcyid92 _agcyid93 _agcyid94 _agcyid95 _agcyid96 _agcyid97 _agcyid98 _agcyid99 _agcyid100 _agcyid101 _agcyid102 _agcyid103 _agcyid104 _agcyid105 _agcyid106 _agcyid107 _agcyid108 _agcyid109 _agcyid110 _agcyid111 _agcyid112 _agcyid113 _agcyid114 _agcyid115 _agcyid116 _agcyid117 _agcyid118 _agcyid119 _agcyid120 _agcyid121 _agcyid122 _agcyid123 _agcyid124 _agcyid125 _agcyid126 _agcyid127 _agcyid128 _agcyid129 _agcyid130 _agcyid131 _agcyid132 _agcyid133 _agcyid134 _agcyid135 _agcyid136 _agcyid137 _agcyid138 _agcyid139 _agcyid140 _agcyid141 _agcyid142 _agcyid143 _agcyid144 _agcyid145 _agcyid146 _agcyid147 _agcyid148 _agcyid149 _agcyid150 _agcyid151 _agcyid152 _agcyid153 _agcyid154 _agcyid155 _agcyid156 _agcyid157 _agcyid158 _agcyid159 _agcyid160 _agcyid161 _agcyid162 _agcyid163 _agcyid164 _agcyid165 _agcyid166 _agcyid167 _agcyid168 _agcyid169 _agcyid170 _agcyid171 _agcyid172 _agcyid173 _agcyid174 _agcyid175 _agcyid176 _agcyid177 _agcyid178 _agcyid179 _agcyid180 _agcyid181 _agcyid182 _agcyid183 _agcyid184 _agcyid185 _agcyid186 _agcyid187 _agcyid188 _agcyid189 _agcyid190 _agcyid191 _agcyid192 _agcyid193 _agcyid194 _agcyid195 _agcyid196 _agcyid197 _agcyid198 _agcyid199 _agcyid200 _agcyid201 _agcyid202 _agcyid203 _agcyid204 _agcyid205 _agcyid206 _agcyid207 _agcyid208 _agcyid209 _agcyid210 _agcyid211 _agcyid212 _agcyid213 _agcyid214 _agcyid215 _agcyid216 _agcyid217 _agcyid218 _agcyid219 _agcyid220 _agcyid221 _agcyid222 _agcyid223 _agcyid224 _agcyid225 _agcyid226 _agcyid227 _agcyid228 _agcyid229 _agcyid230 _agcyid231 _agcyid232 _agcyid233 _agcyid234 _agcyid235 _agcyid236 _agcyid237 _agcyid238 _agcyid239 _agcyid240 _agcyid241 _agcyid242 _agcyid243 _agcyid244 _agcyid245 _agcyid246 _agcyid247 _agcyid248 _agcyid249 _agcyid250 _agcyid251 _agcyid252 _agcyid253 _agcyid254 _agcyid255 _agcyid256 _agcyid257 _agcyid258 _agcyid259 _agcyid260 _agcyid261 _agcyid262 _agcyid263 _agcyid264 _agcyid265 _agcyid266 _agcyid267 _agcyid268 _agcyid269 _agcyid270 _agcyid271 _agcyid272 _agcyid273 _agcyid274 _agcyid275 _agcyid276 _agcyid277 _agcyid278 _agcyid279 _agcyid280 _agcyid281 _agcyid282 _agcyid283 _agcyid284 _agcyid285 _agcyid286 _agcyid287 _agcyid288 _agcyid289 _agcyid290 _agcyid291 _agcyid292 _agcyid293 _agcyid294 _agcyid295 _agcyid296 _agcyid297 _agcyid298 _agcyid299 _agcyid300 _agcyid301 _agcyid302 _agcyid303 _agcyid304 _agcyid305 _agcyid306 _agcyid307 _agcyid308 _agcyid309 _agcyid310 _agcyid311 _agcyid312 _agcyid313 _agcyid314 _agcyid315 _agcyid316 _agcyid317 _agcyid318 _agcyid319 _agcyid320 _agcyid321 _agcyid322 _agcyid323 _agcyid324 _agcyid325 _agcyid326 _agcyid327 _agcyid328 _agcyid329 _agcyid330 _agcyid331 _agcyid332 _agcyid333 _agcyid334 _agcyid335 _agcyid336 _agcyid337 _agcyid338 _agcyid339 _agcyid340 _agcyid341 _agcyid342 _agcyid343 _agcyid344 _agcyid345 _agcyid346 _agcyid347 _agcyid348 _agcyid349 _agcyid350 _agcyid351 _agcyid352 _agcyid353 _agcyid354 _agcyid355 _agcyid356 _agcyid357 _agcyid358 _agcyid359 _agcyid360 _agcyid361 _agcyid362 _agcyid363 _agcyid364 _agcyid365 _agcyid366 _agcyid367 _agcyid368 _agcyid369 _agcyid370 _agcyid371 _agcyid372 _agcyid373 _agcyid374 _agcyid375 _agcyid376 _agcyid377 _agcyid378 _agcyid379 _agcyid380 _agcyid381 _agcyid382 _agcyid383 _agcyid384 _agcyid385 _agcyid386 _agcyid387 _agcyid388 _agcyid389 _agcyid390 _agcyid391 _agcyid392 _agcyid393 _agcyid394 _agcyid395 _agcyid396 _agcyid397 _agcyid398 _agcyid399 _agcyid400 _agcyid401 _agcyid402 _agcyid403 _agcyid404 _agcyid405 _agcyid406 _agcyid407 _agcyid408 _agcyid409 _agcyid410 _agcyid411 _agcyid412 _agcyid413 _agcyid414 _agcyid415 _agcyid416 _agcyid417 _agcyid418 _agcyid419 _agcyid420 _agcyid421 _agcyid422 _agcyid423 _agcyid424 _agcyid425 _agcyid426 _agcyid427 _agcyid428 _agcyid429 _agcyid430 _agcyid431 _agcyid432 _agcyid433 _agcyid434 _agcyid435 _agcyid436 _agcyid437 _agcyid438 _agcyid439 _agcyid440 _agcyid441 _agcyid442 _agcyid443 _agcyid444 _agcyid445 _agcyid446 _agcyid447 _agcyid448 _agcyid449 _agcyid450 _agcyid451 _agcyid452 _agcyid453 _agcyid454 _agcyid455 _agcyid456 _agcyid457 _agcyid458 _agcyid459 _agcyid460 _agcyid461 _agcyid462 _agcyid463 _agcyid464 _agcyid465 _agcyid466 _agcyid467 _agcyid468 _agcyid469 _agcyid470 _agcyid471 _agcyid472 _agcyid473 _agcyid474 _agcyid475 _agcyid476 _agcyid477 _agcyid478 _agcyid479 _agcyid480 _agcyid481 _agcyid482 _agcyid483 _agcyid484 _agcyid485 _agcyid486 _agcyid487 _agcyid488 _agcyid489 _agcyid490 _agcyid491 _agcyid492 _agcyid493 _agcyid494 _agcyid495 _agcyid496 _agcyid497 _agcyid498 _agcyid499 _agcyid500 _agcyid501 _agcyid502 _agcyid503 _agcyid504 _agcyid505 _agcyid506 _agcyid507 _agcyid508 _agcyid509 _agcyid510 _agcyid511 _agcyid512 _agcyid513 _agcyid514 _agcyid515 _agcyid516 _agcyid517 _agcyid518 _agcyid519 _agcyid520 _agcyid521 _agcyid522 _agcyid523 _agcyid524 _agcyid525 _agcyid526 _agcyid527 _agcyid528 _agcyid529 _agcyid530 _agcyid531 _agcyid532 _agcyid533 _agcyid534 _agcyid535 _agcyid536 _agcyid537 _agcyid538 _agcyid539 _agcyid540 _agcyid541 _agcyid542 _agcyid543 _agcyid544 _agcyid545 _agcyid546 _agcyid547 _agcyid548 _agcyid549 _agcyid550 _agcyid551 _agcyid552 _agcyid553 _agcyid554 _agcyid555 _agcyid556 _agcyid557 _agcyid558 _agcyid559 _agcyid560 _agcyid561 _agcyid562 _agcyid563 _agcyid564 _agcyid565 _agcyid566 _agcyid567 _agcyid568 _agcyid569 _agcyid570 _agcyid571 _agcyid572 _agcyid573 _agcyid574 _agcyid575 _agcyid576 _agcyid577 _agcyid578 _agcyid579 _agcyid580 _agcyid581 _agcyid582 _agcyid583 _agcyid584 _agcyid585 _agcyid586 _agcyid587 _agcyid588 _agcyid589 _agcyid590 _agcyid591 _agcyid592 _agcyid593 _agcyid594 _agcyid595 _agcyid596 _agcyid597 _agcyid598 _agcyid599 _agcyid600 _agcyid601 _agcyid602 _agcyid603 _agcyid604 _agcyid605 _agcyid606 _agcyid607 _agcyid608 _agcyid609 _agcyid610 _agcyid611 _agcyid612 _agcyid613 _agcyid614 _agcyid615 _agcyid616 _agcyid617 _agcyid618 _agcyid619 _agcyid620 _agcyid621 _agcyid622 _agcyid623 _agcyid624 _agcyid625 _agcyid626 _agcyid627 _agcyid628 _agcyid629 _agcyid630 _agcyid631 _agcyid632 _agcyid633 _agcyid634 _agcyid635 _agcyid636 _agcyid637 _agcyid638 _agcyid639 _agcyid640 _agcyid641 _agcyid642 _agcyid643 _agcyid644 _agcyid645 _agcyid646 _agcyid647 _agcyid648 _agcyid649 _agcyid650 _agcyid651 _agcyid652 _agcyid653 _agcyid654 _agcyid655 _agcyid656 _agcyid657 _agcyid658 _agcyid659 _agcyid660 _agcyid661 _agcyid662 _agcyid663 _agcyid664 _agcyid665 _agcyid666 _agcyid667 _agcyid668 _agcyid669 _agcyid670 _agcyid671 _agcyid672 _agcyid673 _agcyid674 _agcyid675 _agcyid676 _agcyid677 _agcyid678 _agcyid679 _agcyid680 _agcyid681 _agcyid682 _agcyid683 _agcyid684 _agcyid685 _agcyid686 _agcyid687 _agcyid688 _agcyid689 _agcyid690 _agcyid691 _agcyid692 _agcyid693 _agcyid694 _agcyid695 _agcyid696 _agcyid697 _agcyid698 _agcyid699 _agcyid700 _agcyid701 _agcyid702 _agcyid703 _agcyid704 _agcyid705 _agcyid706 _agcyid707 _agcyid708 _agcyid709 _agcyid710 _agcyid711 _agcyid712 _agcyid713 _agcyid714 _agcyid715 _agcyid716 _agcyid717 _year1 _year2 _year3 _year4 _year5 _year6)

	mat A = [A \ `c' , `r(delta)']
}

mat list A
*/


clear
// this summarizes results above
input r2 delta
 .59128494  40.076542
       .65  28.354737
        .7  22.700644
       .75  18.926579
        .8  16.228527
        .9   12.62815
       .95  11.367214
         1  10.335229
end


tw ///
	(line delta r2 , lw(.5) ) , ///
	yline(10 , lw(.5) lc(gray) lp(--) ) yline(1 , lw(.5) ) ///
	ylabel(40 "40" 30 "30" 20 "20" 10 "10" 1 "1", add) ///
	xlabel(.6 "1.3R{superscript:2}" 0.7 "0.7" 0.8 "0.8" 0.9 "0.9" 1 "1", add nogrid) ///
	yti("{it:{&delta}}") xti("R{superscript:2}{sub:max}") ///
	scheme(tufte)
	
gr export ${figdir}/fig_oster_plot.pdf , replace
