*=======================================
*** Robustness Checks
*=======================================
cap cd "C:/Users/laiwz/OneDrive - University of Maryland/Research/anticorruption_civil_servant/jle_final/replication"

global data ./data
global figdir ./figure
global tabdir ./table

graph set window fontface "Times New Roman"



*=======================================
**# Global variables
*=======================================
global control exp_unlimited polaff_unlimited educ_vocational educ_college lngdpp
global control_int ${control}

foreach v in $control {
	global control_int ${control_int} c.`v'#i.year
}


use ${data}/data_for_analysis, clear
unique agcyid


gen inspectbranch = inspectagcy*(main==0)
recode yr_inspectagcy (.=0)
keep if main==1
duplicates drop agcyid , force
codebook yr_inspectagcy





*=======================================
**# Permutation test: timing
*=======================================

**** Define the program
cap program drop placebo

program def placebo

**** load data
use ${data}/data_for_analysis, clear

gen lnexaminee = ln(examinee+1)
gen lnvacancy = ln(vacancy+1)
gen lncomp = ln(1+comp)
gen main = (system==agcy)
gen inspectmain = inspectagcy*main
gen inspectbranch = inspectagcy*(main==0)
recode yr_inspectagcy (.=0)


**** Balancing
fillin agcyid year
gen imputed = _fillin

foreach v of var yr_inspectagcy main provcd {
	bysort agcyid: egen temp = max(`v')
	replace `v' = temp if missing(`v')
	drop temp
}

replace inspectagcy = (year>=yr_inspectagcy)
replace inspectmain = inspectagcy*main


// fill missing comp and covariates
qui reg comp inspectmain $control i.agcyid i.year

foreach v of var $control {
	if "`v'"=="lngdpp" {
		bysort provcd (year): egen temp = mean(`v')
		replace `v' = temp if missing(`v')
		drop temp
	}
	else {
		bysort agcyid (year): egen temp = mean(`v')
		replace `v' = temp if missing(`v')
		drop temp
	}
}

predict temp
replace comp = temp if missing(comp)
drop temp


// counterfactual timing
preserve
*keep if main==1 //& yr_inspectagcy>0
keep agcyid //yr_inspectagcy main
duplicates drop agcyid , force
*duplicates drop agcyid yr_inspectagcy main, force
*tab yr_inspectagcy

gen rnum = rnormal()
sort rnum
keep in 1/101

gen fake_yr_inspectgacy = .
replace fake_yr_inspectgacy = 2013 in 1/3
replace fake_yr_inspectgacy = 2014 in 4/5
replace fake_yr_inspectgacy = 2015 in 6/30
replace fake_yr_inspectgacy = 2016 in 31/81
replace fake_yr_inspectgacy = 2017 in 82/101

tempfile fake_timing
save `fake_timing'
restore

// merge fake timing
merge m:1 agcyid using `fake_timing', nogen
gen fake_inspectmain = (year>=fake_yr_inspectgacy)
recode fake_yr_inspectgacy (.=0)

bysort agcyid: egen everinspected = max(fake_inspectmain)
gen first_inspect = fake_yr_inspectgacy if everinspected
gen never_inspect = !everinspected //(first_inspect==.)

codebook fake_inspectmain everinspected first_inspect never_inspect


**** DiD regression
reghdfe comp fake_inspectmain $control imputed , a(agcyid year )
scalar beta = _b[fake_inspectmain]


**** Event study
gen gap = year-fake_yr_inspectgacy

forvalues i=1/5 {
	local j = `i'-6
	local k = abs(`j')
	gen d_`k' = (gap==`j')
}

forvalues i=0/4 {
	gen d`i' = (gap==`i')
}

reghdfe comp d_5-d_2 o.d_1 d0-d4 $control imputed , a(agcyid year )

forvalues i=1/5 {
	local j = `i'-6
	local k = abs(`j')
	scalar b_`k' = _b[d_`k']
}

forvalues i=0/4 {
	scalar b`i' = _b[d`i']
}


***** Sun and Abraham 2020
eventstudyinteract comp fake_inspectmain , absorb(i.agcyid i.year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control} imputed)
mat A = r(table)
mat A = A'
scalar bsa = A[1,1]

eventstudyinteract comp d_5-d_2 d0-d4 d_1 , absorb(i.agcyid i.year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control} imputed)

mat A = r(table)
mat A = A'


forvalues i=1/5 {
	local j = `i'-6
	local k = abs(`j')
	scalar bsa_`k' = A[`i',1]
}

forvalues i=0/4 {
	local z = `i'+5
	scalar bsa`i' = A[`z',1]
}


end



**# Run simulation
*simulate ///
	b=beta ///
	b_5=b_5 b_4=b_4 b_3=b_3 b_2=b_2 ///
	b0=b0 b1=b1 b2=b2 b3=b3 b4=b4 ///
	bsa=bsa ///
	bsa_5=bsa_5 bsa_4=bsa_4 bsa_3=bsa_3 bsa_2=bsa_2 ///
	bsa0=bsa0 bsa1=bsa1 bsa2=bsa2 bsa3=bsa3 bsa4=bsa4 , ///
	reps(1000) seed(2022) saving(${data}/data_placebo_time, replace) : placebo

	
	

**# Figure 11: Visualize results for DID
use ${data}/data_placebo_time, clear

/// DiD
local bb = -69.352 //-74.718
gen rej = (abs(bsa)>abs(`bb'))
sum rej
local pval = string(round(`r(mean)', .001))
drop rej

local xpos = `bb'*.9

tw ///
	(hist bsa, fcolor(white) lcolor(black) ), ///
	xsc(range(-80 40)) xlab(-80(20)40) xline(`bb' ,  lw(.5) ) ///
	xti("Counterfactual Estiamte {it:{&beta}}") yti("Density" ) xlab(, nogr format(%9.0fc)) ///
	text(.04 `xpos' "Actual {it:{&beta}} = `bb'" "{it:p}-value = `pval'" , place(4) j(left) margin(l+1 r+1 t+1 b+1) size(small) ) ///
	scheme(tufte)

	gr export ${figdir}/fig_permutation_dd.pdf , replace

	

	
	
		
	
	
**# Figure OA5: Event study	
preserve
use ${data}/eventstudy_sumabraham_balance, clear
renvars , subst("A" "")

gen x = _n-6 if _n<=4
replace x = _n-5 if _n>4
replace x = -1 in L
sort x

forvalues i=1/5 {
	local j = `i'-6
	local k = abs(`j')
	global bsa_`k' = b in `i'
}

forvalues i=0/4 {
	local z = `i'+6
	global bsa`i' = b in `z'
}

restore



local v bsa0
local bb = round($`v' , .001)
gen rej = (`v'<`bb')
sum rej 
local pval = string(round(`r(mean)', .001))
drop rej
local xpos = `bb'*.9

tw ///
	(hist `v' , fcolor(white) lcolor(black)) , xline(`bb' , lw(.5) ) ///
	xti(" " "Counterfactual Estiamte {&beta}{sub:0}") yti("Density") xlab(, nogr format(%9.0fc)) ///
	text(.05 `xpos' "Actual {&beta}{sub:0} = `bb' " "p-value = `pval'" , place(4) j(left) margin(l+1 r+1 t+1 b+1) size(small) ) ///
	scheme(tufte) name(fig_permutation_es0 , replace)
	



local v bsa1
local bb = round($`v' , .001)
gen rej = (`v'<`bb')
sum rej 
local pval = string(round(`r(mean)', .001))
drop rej
local xpos = `bb'*.9

tw ///
	(hist `v' , fcolor(white) lcolor(black)) , xline(`bb' , lw(.5) ) ///
	xti(" " "Counterfactual Estiamte {&beta}{sub:1}") yti("Density") xlab(, nogr format(%9.0fc)) ///
	text(.04 `xpos' "Actual {&beta}{sub:1} = `bb' " "p-value = `pval'" , place(4) j(left) margin(l+1 r+1 t+1 b+1) size(small) ) ///
	scheme(tufte) name(fig_permutation_es1 , replace)
	


local v bsa2
local bb = round($`v' , .001)
gen rej = (`v'<`bb')
sum rej 
local pval = string(round(`r(mean)', .001))
drop rej
local xpos = `bb'*.9

tw ///
	(hist `v' , fcolor(white) lcolor(black)) , xline(`bb' , lw(.5) ) ///
	xti(" " "Counterfactual Estiamte {&beta}{sub:2}") yti("Density") xlab(, nogr format(%9.0fc)) ///
	text(.025 `xpos' "Actual {&beta}{sub:2} = `bb' " "p-value = `pval'" , place(4) j(left) margin(l+1 r+1 t+1 b+1) size(small) ) ///
	scheme(tufte) name(fig_permutation_es2 , replace)
	

local v bsa3
local bb = round($`v' , .001)
gen rej = (`v'<`bb')
sum rej 
local pval = string(round(`r(mean)', .001))
drop rej
local xpos = `bb'*.9

tw ///
	(hist `v' , fcolor(white) lcolor(black)) , xline(`bb' , lw(.5) ) ///
	xti(" " "Counterfactual Estiamte {&beta}{sub:3}") yti("Density") xlab(, nogr format(%9.0fc)) ///
	text(.015 `xpos' "Actual {&beta}{sub:3} = `bb' " "p-value = `pval'" , place(4) j(left) margin(l+1 r+1 t+1 b+1) size(small) ) ///
	scheme(tufte) name(fig_permutation_es3 , replace)


	
	
	

local v bsa4
local bb = round($`v' , .001)
gen rej = (`v'<`bb')
sum rej 
local pval = string(round(`r(mean)', .001))
drop rej
local xpos = `bb'*.9

tw ///
	(hist `v' , fcolor(white) lcolor(black)) , xline(`bb' , lw(.5) ) ///
	xti(" " "Counterfactual Estiamte {&beta}{sub:4}") yti("Density") xlab(, nogr format(%9.0fc)) ///
	text(.008 `xpos' "Actual {&beta}{sub:4} = `bb' " "p-value = `pval'" , place(4) j(left) margin(l+1 r+1 t+1 b+1) size(small) ) ///
	scheme(tufte) name(fig_permutation_es4 , replace)
	
	

	
	
	

gr combine ///
	fig_permutation_es0 fig_permutation_es1 fig_permutation_es2 ///
	fig_permutation_es3 fig_permutation_es4 , ///
	rows(3) scheme(tufte)
	
	gr export  ${figdir}/fig_permutation_es.pdf , replace
