*=======================================
*** Figure OA7: Additional ES Results
*=======================================
cap cd "C:/Users/laiwz/OneDrive - University of Maryland/Research/anticorruption_civil_servant/jle_final/replication"

global data ./data
global figdir ./figure
global tabdir ./table

graph set window fontface "Times New Roman"


global control exp_unlimited polaff_unlimited educ_vocational educ_college lngdpp
global controlsys exp_unlimited polaff_unlimited educ_vocational educ_college lngdpp lntot_funding







*=======================================
*** Examinee
*=======================================
use ${data}/data_for_analysis, clear

gen inspectbranch = inspectagcy*(main==0)
recode yr_inspectagcy (.=0)

gen gap = year-yr_inspectagcy
tab gap

forvalues i=1/5 {
	local j = `i'-6
	local k = abs(`j')
	gen d_`k' = (gap==`j')*(yr_inspectagcy>0)*main
}

forvalues i=0/4 {
	gen d`i' = (gap==`i')*(yr_inspectagcy>0)*main
}


// TWFE
reghdfe examinee d_5-d_2 o.d_1 d0-d4 vacancy $control , a(agcyid year ) cl(agcyid)
parmest , saving(${data}/eventstudy_examinee , replace) format(parm estimate min95 max95)
test d_5 d_4 d_3 d_2
test d0 d1 d2 d3 d4


/// Sun and Abraham 2020
eventstudyinteract examinee d_5-d_2 d0-d4 d_1 , absorb(i.agcyid i.year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control} vacancy) vce(cl agcyid)
mat A = r(table)
mat A = A'
xsvmat A , names(matcol) saving(${data}/eventstudy_sumabraham_examinee , replace)




*=========================
*** Plotting
*=========================
use ${data}/eventstudy_sumabraham_examinee, clear
renvars , subst("A" "")

gen min95 = b-1.96*se
gen max95 = b+1.96*se

gen x = _n-6 if _n<=4
replace x = _n-5 if _n>4
replace x = -1 in L
sort x

gen sun = 1


/// results of orig ES
preserve
use ${data}/eventstudy_examinee , clear
keep in 1/10

ren estimate b
ren stderr se

gen x = _n-6
gen zero = 0
gen x1 = -6 in 1
replace x1 = 5 in 2
gen sun = 0

tempfile temp
save `temp'
restore

append using `temp'

replace x = x-.1 if sun==0
replace x = x+.1 if sun==1

tw ///
	(rcap min95 max95 x if sun==0 , lcolor(gray) ) ///
	(sc b x if sun==0 , msize(small) msymbol(t) lcolor(gray) mcolor(gray) lpattern(--) ) ///
	(rcap min95 max95 x if sun==1 , lcolor(black) ) ///
	(sc b x if sun==1 , msize(small) msymbol(o) lcolor(black) mcolor(black) lpattern(solid) ), ///
	xline(-1, lpattern(--) lc(gs10)) yline(0, lpattern(--) lc(gs10)) ///
	xti("Year Relative to Inspection") xlab(-5(1)4 , nogr) xsc(range(-6 5)) ///
	yti("Inspection Effect on AHR") ylab(, nogr format(%9.0fc)) ///
	text(-5000 -3 "Prior Inspection" -5000 1.5 "Post Inspection") scheme(tufte) ///
	leg(order(4 "Sun and Abraham (2021)" 2 "TWFE") ring(0) pos(1) region(color(none)) )
	
	gr export ${figdir}/fig_eventstudy_examinee.pdf, replace


erase ${data}/eventstudy_examinee.dta
erase ${data}/eventstudy_sumabraham_examinee.dta











*=======================================
*** Budegetary data
*=======================================
use ${data}/data_for_analysis, clear

// collapse to system level data
*keep if agcy==system
collapse (rawsum) examinee vacancy (max) yr_inspectagcy (mean) $control [weight=vacancy] , by(system sysid year)

cap drop inspectmain
gen inspectmain = (year>=yr_inspectagcy)


// merge budget data and prepare
cap drop agcy
ren system agcy
merge m:1 agcy year using ${data}/data_budget, keep(1 3) nogen

gen sangong = car+recept+abroad
gen fringe = gjj+housing

gen fr_sangong = sangong/tot_funding
gen fr_fringe = fringe/tot_funding

gen lntot_funding = ln(tot_funding)
gen lnsangong = ln(sangong)
gen lnfringe = ln(fringe)
gen lnwage = ln(wage)
gen lntotal = ln(fringe+wage)

tab sysid , gen(sysdummy)
tab year , gen(yeardummy)
cap tab agcyid , gen(agcydummy)

bysort sysid: egen everinspected = max(inspectmain)
gen first_inspect = yr_inspectagcy if everinspected
gen never_inspect = !everinspected //(first_inspect==.)

gen gap = year-yr_inspectagcy
tab gap

forvalues i=1/5 {
	local j = `i'-6
	local k = abs(`j')
	gen d_`k' = (gap==`j')*(yr_inspectagcy>0)
}

forvalues i=0/4 {
	gen d`i' = (gap==`i')*(yr_inspectagcy>0)
}

replace d_4 = d_4+d_5

*eventstudyinteract lntotal inspectmain , absorb(i.sysid i.year ) cohort(first_inspect) control_cohort(never_inspect) covariates(${control} ) vce(cl sysid)


//// ES
foreach v of var lnsangong lntotal {

reghdfe `v' d_4-d_2 o.d_1 d0-d4 $control , a(sysid year) cl(sysid)
parmest , saving(${data}/eventstudy_`v' , replace) format(parm estimate min95 max95)

eventstudyinteract `v' d_4-d_2 d0-d4 d_1 , absorb(i.sysid i.year ) cohort(first_inspect) control_cohort(never_inspect) covariates(${control} ) vce(cl sysid)
mat A = r(table)
mat A = A'
xsvmat A , names(matcol) saving(${data}/eventstudy_sumabraham_`v' , replace)

}







**** Plotting
/// sangong
use ${data}/eventstudy_sumabraham_lnsangong, clear
renvars , subst("A" "")

gen min95 = b-1.96*se
gen max95 = b+1.96*se

gen x = _n-5 if _n<=3
replace x = _n-4 if _n>3
replace x = -1 in L
sort x

gen sun = 1


/// results of orig ES
preserve
use ${data}/eventstudy_lnsangong , clear
keep in 1/9

ren estimate b
ren stderr se

gen x = _n-5
gen zero = 0
gen sun = 0

tempfile temp
save `temp'
restore

append using `temp'

replace x = x-.1 if sun==0
replace x = x+.1 if sun==1

tw ///
	(rcap min95 max95 x if sun==0 , lcolor(gray) ) ///
	(sc b x if sun==0 , msize(small) msymbol(t) lcolor(gray) mcolor(gray) lpattern(--) ) ///
	(rcap min95 max95 x if sun==1 , lcolor(black) ) ///
	(sc b x if sun==1 , msize(small) msymbol(o) lcolor(black) mcolor(black) lpattern(solid) ), ///
	xline(-1, lpattern(--) lc(gs10)) yline(0, lpattern(--) lc(gs10)) ///
	xti("Year Relative to Inspection") xlab(-5(1)4 , nogr) xsc(range(-5 5)) ///
	yti("Inspection Effect on ln(ETC)") ///
	text(-.75 -3 "Prior Inspection" -.75 1.5 "Post Inspection") scheme(tufte) ///
	leg(order(4 "Sun and Abraham (2021)" 2 "TWFE" ) ring(0) pos(1) region(color(none)))
	
	gr export ${figdir}/fig_eventstudy_lnsangong.pdf, replace


erase ${data}/eventstudy_sumabraham_lnsangong.dta
erase ${data}/eventstudy_lnsangong.dta






/// totals
use ${data}/eventstudy_sumabraham_lntotal, clear
renvars , subst("A" "")

gen min95 = b-1.96*se
gen max95 = b+1.96*se

gen x = _n-5 if _n<=3
replace x = _n-4 if _n>3
replace x = -1 in L
sort x

gen sun = 1


/// results of orig ES
preserve
use ${data}/eventstudy_lntotal , clear
keep in 1/9

ren estimate b
ren stderr se

gen x = _n-5
gen zero = 0
gen sun = 0

tempfile temp
save `temp'
restore

append using `temp'

replace x = x-.1 if sun==0
replace x = x+.1 if sun==1

tw ///
	(rcap min95 max95 x if sun==0 , lcolor(gray) ) ///
	(sc b x if sun==0 , msize(small) msymbol(t) lcolor(gray) mcolor(gray) lpattern(--) ) ///
	(rcap min95 max95 x if sun==1 , lcolor(black) ) ///
	(sc b x if sun==1 , msize(small) msymbol(o) lcolor(black) mcolor(black) lpattern(solid) ), ///
	xline(-1, lpattern(--)) yline(0, lpattern(--)) ///
	xti("Year Relative to Inspection") xlab(-4(1)4 , nogr) xsc(range(-4.5 4.5)) ///
	yti("Inspection Effect on ln(Wages+Perks)") ///
	text(-.5 -3 "Prior Inspection" -.5 1.5 "Post Inspection") scheme(tufte) ///
	leg(order(4 "Sun and Abraham (2021)" 2 "TWFE" ) ring(0) pos(1) region(color(none)))
	
	gr export ${figdir}/fig_eventstudy_lntotal.pdf, replace


erase ${data}/eventstudy_sumabraham_lntotal.dta
erase ${data}/eventstudy_lntotal.dta
