cap cd "C:/Users/laiwz/OneDrive - University of Maryland/Research/anticorruption_civil_servant/jle_final/replication"

global data ./data
global figdir ./figure
global tabdir ./table

graph set window fontface "Times New Roman"





*=======================================
**# Table 6
*=======================================
global control exp_unlimited polaff_unlimited educ_vocational educ_college lngdpp

use ${data}/data_for_analysis, clear

// collapse to system level data
*keep if agcy==system
collapse (sum) examinee vacancy (max) yr_inspectagcy (mean) $control [weight=vacancy] , by(system sysid year)

gen lnexaminee = ln(examinee+1)
gen lnvacancy = ln(vacancy+1)
gen comp = examinee/vacancy
recode yr_inspectagcy (.=0)
*gen main = (system==agcy)
*gen inspectmain = (year>=yr_inspectagcy)*main
gen inspectmain = (year>=yr_inspectagcy)

bysort sysid: egen everinspected = max(inspectmain)
gen first_inspect = yr_inspectagcy if everinspected
gen never_inspect = !everinspected //(first_inspect==.)


// merge budget data and prepare
cap drop agcy
ren system agcy
merge m:1 agcy year using ${data}/data_budget, keep(1 3) nogen

gen sangong = car+recept+abroad
gen fringe = gjj+housing

gen fr_sangong = sangong/tot_funding
gen fr_fringe = fringe/tot_funding

gen lntot_funding = ln(tot_funding)
gen lnsangong = ln(sangong)
gen lnfringe = ln(fringe)
gen lnwage = ln(wage)
gen lntotal = ln(fringe+wage)

tab sysid , gen(sysdummy)
tab year , gen(yeardummy)
cap tab agcyid , gen(agcydummy)






*=======================================
*** Pecuniary returns
*=======================================
	
eststo clear

//// ETC
eventstudyinteract lnsangong inspectmain , absorb(sysid year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control}) vce(cl sysid)
	mat b = e(b_iw) , e(b)
	local names: colnames b
	mata: st_matrix("V", blockdiag(st_matrix("e(V_iw)"), st_matrix("e(V)")))
	matrix rownames V = `names'
	matrix colnames V = `names'
	sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
	local ymean = `r(mean)'
	local N = e(N_full)
	local r2 = e(r2)

eststo: ereturn post b V , depn("`e(depvar)'")
estadd scalar N_full = `N'
estadd scalar r2 = `r2'
estadd scalar ymean = `ymean'
estadd local sysfe "\multicolumn{1}{c}{Yes}" , replace
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{Yes}", replace


//// Fringe pay & wage
eventstudyinteract lntotal inspectmain , absorb(sysid year) cohort(first_inspect) control_cohort(never_inspect) covariates(${control}) vce(cl sysid)
	mat b = e(b_iw) , e(b)
	local names: colnames b
	mata: st_matrix("V", blockdiag(st_matrix("e(V_iw)"), st_matrix("e(V)")))
	matrix rownames V = `names'
	matrix colnames V = `names'
	sum `e(depvar)' if e(sample) & everinspected & inspectmain==0
	local ymean = `r(mean)'
	local N = e(N_full)
	local r2 = e(r2)

eststo: ereturn post b V , depn("`e(depvar)'")
estadd scalar N_full = `N'
estadd scalar r2 = `r2'
estadd scalar ymean = `ymean'
estadd local sysfe "\multicolumn{1}{c}{Yes}" , replace
estadd local yearfe "\multicolumn{1}{c}{Yes}", replace
estadd local control "\multicolumn{1}{c}{Yes}", replace






**** Make a table
lab var comp "AHR"
lab var inspectmain "Inspection"
lab var lnfringe "ln(Perks)"
lab var lnsangong "ln(ETC)"
lab var lnwage "ln(Wage)"
lab var lntotal "ln(Wages \& Perks)"

esttab using ${tabdir}/table_mechanism_pecuniary.tex , replace ///
	b(3) se(3) star(+ .1 * .05 ** .01) ///
	keep(inspectmain) label ///
	s(N_full r2 sysfe yearfe control , lab("\$N\$" "\$R^2\$" "Branch FE" "Year FE" "Covariates" ) fmt(%9.0fc 3 0 0 0) ) ///
	mgroups("Public Funds (\$m\$)" "Legal Income (\$w\$)", pattern(1 1 ) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	nogaps nonotes nolz booktabs alignment(D{.}{.}{-1}) prefoot("")

