cap cd "C:/Users/laiwz/OneDrive - University of Maryland/Research/anticorruption_civil_servant/jle_final/replication"

global data ./data
global figdir ./figure
global tabdir ./table

graph set window fontface "Times New Roman"





***************************************
** program
** bivariate correlated unif
***************************************
cap program drop model

program def model , rclass

*** inputs
args ///
	mu_a mu_t ///
	rho0 rho1 rho2 rho3 rho4 ///
	m_lb m_ub w ///
	al p_lb p_ub

*** clear memory
clear
set obs 10000


*** simulate theta and a
forvalues i=0(1)4 {

	gen double u = runiform(0,1)
	gen double v = runiform(0,1)
	
	local r = `rho`i''
	local a = 0.5*(sqrt((49+`r')/(1+`r'))-5)
	
	gen double w = rbeta(`a',1)
	gen double x = u
	gen double y = .
	replace y = abs(w-x) if v<0.5
	replace y = 1-abs(1-w-x) if v>=0.5
	
	replace x = x
	replace y = y
	
	gen double a`i' = x*`mu_a'
	gen double t`i' = y*`mu_t'
	
	drop u v w x y

}


*** parameterization

// legal income
gen double w = `w'

// m: bureaucratic power
if `m_lb'==`m_ub' {
	gen double m = `m_lb'
}
else {
	gen double m = runiform(`m_lb',`m_ub') in 1 // funds at discretion
	egen double temp = max(m)
	replace m = temp
	drop temp
}

// p: corruption detection
if `p_lb'==`p_ub' {
	gen double p = `p_lb'
}
else {
	gen double p = runiform(`p_lb',`p_ub') in 1 // prob of detecting misconduct
	egen double temp = max(p)
	replace p = temp
	drop temp
}


*** join bureaucracy or not
sum p
local q = `r(mean)'

if 1-(1+`al')*`q'>0 {
	local ahat = 1-(1+`al')*`q'
}
else {
	local ahat = 0
}



foreach i in 0 1 2 3 4 {

gen double x`i' = 1
replace x`i' = ( (1-a`i')/((1+`al')*p) )^(1/`al') if inrange(a`i',`ahat',1)
replace x`i' = 0 if a`i'>1

gen double ub`i' = w + a`i'*(1-x`i')*m + (1-p*(x`i')^`al')*x`i'*m // utitlity if embezzling
gen double un`i' = t`i'
gen double join`i' = (ub`i'>un`i')


*** statistics
// bureaucrats
sum join`i'
ret scalar ss`i' = `r(mean)' // applicant pool size

sum x`i' if join`i'
ret scalar cc`i' = `r(mean)' // corruption incidence conditional on joinning

sum a`i' if join`i'
ret scalar aa`i' = `r(mean)' // avg bureaucratic altruism

sum t`i' if join`i'
ret scalar tt`i' = `r(mean)' // avg bureaucratic ability

}

// anticorruption policy
sum m
ret scalar mm = `r(mean)' // funds at discretion

sum p
ret scalar pp = `r(mean)' // oversight strength

end





************************************************
**# Figure 13 a&b, Figure OA8 a
***comparative statics wrt q
************************************************
/// simulattion
/* Variables
args ///
	mu_a mu_t ///
	rho0 rho1 rho2 rho3 rho4 ///
	m_lb m_ub w ///
	al p_lb p_ub
*/
	
simulate , seed(2022) reps(1000) saving(${data}/sim_model1 , replace) : model ///
	2 2 ///
	0 .1 .3 -.1 -.3 ///
	3 3 0 ///
	2 0 1

	
	

/// plotting
use ${data}/sim_model1 , clear
global v pp
sort $v

tw ///
	(lowess aa0 $v , lw(.5) mean ) ///
	(lowess aa1 $v , lw(.5) mean ) ///
	(lowess aa2 $v , lw(.5) mean ) ///
	(lowess aa3 $v , lw(.5) mean  ) ///
	(lowess aa4 $v , lw(.5) mean  ) , ///
	yline(1 , lp(l) lc(gray)) ylab(1 "{it:E[a]} = 1" , add) ///
	xlab(, nogr) xti("{it:q}") yti("{it:A}") ///
	leg(order(1 "{it:{&rho}} = 0" 2 "{it:{&rho}} = 0.1" 3 "{it:{&rho}} = 0.3" ///
			4 "{it:{&rho}} = -0.1" 5 "{it:{&rho}} = -0.3") ring(0) pos(11) region(color(none))) ///
	scheme(tufte)

	gr export ${figdir}/fig_model_corr_Ap.pdf , replace
	
	
	
tw ///
	(lowess tt0 $v , lw(.5) mean ) ///
	(lowess tt1 $v , lw(.5) mean ) ///
	(lowess tt2 $v , lw(.5) mean ) ///
	(lowess tt3 $v , lw(.5) mean ) ///
	(lowess tt4 $v , lw(.5) mean ) , ///
	yline(1 , lp(l) lc(gray)) ylab(1 "{it:E[{&theta}]} = 1" , add) ///
	xlab(, nogr) xti("{it:q}") yti("{it:{&Theta}}") ///
	leg(order(1 "{it:{&rho}} = 0" 2 "{it:{&rho}} = 0.1" 3 "{it:{&rho}} = 0.3" ///
			4 "{it:{&rho}} = -0.1" 5 "{it:{&rho}} = -0.3") ring(0) pos(7) region(color(none))) ///
	scheme(tufte)
	
	gr export ${figdir}/fig_model_corr_Tp.pdf , replace

	

tw ///
	(lowess ss0 $v , lw(.5) mean ) ///
	(lowess ss1 $v , lw(.5) mean ) ///
	(lowess ss2 $v , lw(.5) mean ) ///
	(lowess ss3 $v , lw(.5) mean ) ///
	(lowess ss4 $v , lw(.5) mean ) , ///
	yline(1 , lp(l) lc(gray)) ///
	xlab(, nogr) xti("{it:q}") yti("{it:S}") ///
	leg(order(1 "{it:{&rho}} = 0" 2 "{it:{&rho}} = 0.1" 3 "{it:{&rho}} = 0.3" ///
			4 "{it:{&rho}} = -0.1" 5 "{it:{&rho}} = -0.3") ring(0) pos(7) region(color(none))) ///
	scheme(tufte)

	gr export ${figdir}/fig_model_corr_Sp.pdf , replace

	
	

***************************************
**# Figure 13 c&d, Figure OA8 b
*** comparative statics wrt m
***************************************
/*
	mu_a mu_t ///
	rho0 rho1 rho2 rho3 rho4 ///
	m_lb m_ub w ///
	al p_lb p_ub
*/
	
simulate , seed(2022) reps(1000) saving(${data}/sim_model2 , replace) : model ///
	2 2 /// upper bounds of unif. distributions
	0 .1 .3 -.1 -.3 ///
	1 4 0 ///
	2 .5 .5




/// plotting
use ${data}/sim_model2 , clear
gen m = -mm
global v m
sort $v
		
tw ///
	(lowess aa0 $v , lw(.5) mean ) ///
	(lowess aa1 $v , lw(.5) mean ) ///
	(lowess aa2 $v , lw(.5) mean ) ///
	(lowess aa3 $v , lw(.5) mean ) ///
	(lowess aa4 $v , lw(.5) mean ) , ///
	yline(1 , lp(l) lc(gray)) ylab(1 "{it:E[a]} = 1" , add) ///
	xlab(, nogr) xti("{it:-m}") yti("{it:A}" ) ///
	leg(order(1 "{it:{&rho}} = 0" 2 "{it:{&rho}} = 0.1" 3 "{it:{&rho}} = 0.3" ///
			4 "{it:{&rho}} = -0.1" 5 "{it:{&rho}} = -0.3") ring(0) pos(11) region(color(none))) ///
	scheme(tufte)
	
	gr export ${figdir}/fig_model_corr_Am.pdf , replace

	
	
tw ///
	(lowess tt0 $v , lw(.5) mean ) ///
	(lowess tt1 $v , lw(.5) mean ) ///
	(lowess tt2 $v , lw(.5) mean ) ///
	(lowess tt3 $v , lw(.5) mean ) ///
	(lowess tt4 $v , lw(.5) mean ) , ///
	yline(1 , lp(l) lc(gray)) ylab(1 "{it:E[{&theta}]} = 1" , add) ///
	xlab(, nogr) xti("{it:-m}") yti("{it:{&Theta}}") ///
	leg(order(1 "{it:{&rho}} = 0" 2 "{it:{&rho}} = 0.1" 3 "{it:{&rho}} = 0.3" ///
			4 "{it:{&rho}} = -0.1" 5 "{it:{&rho}} = -0.3") ring(0) pos(7) region(color(none))) ///
	scheme(tufte)
	
	gr export ${figdir}/fig_model_corr_Tm.pdf , replace


	
tw ///
	(lowess ss0 $v , lw(.5) mean ) ///
	(lowess ss1 $v , lw(.5) mean ) ///
	(lowess ss2 $v , lw(.5) mean ) ///
	(lowess ss3 $v , lw(.5) mean ) ///
	(lowess ss4 $v , lw(.5) mean ) , ///
	yline(1 , lp(l) lc(gray)) ///
	xlab(, nogr) xti("{it:-m}") yti("{it:S}") ///
	leg(order(1 "{it:{&rho}} = 0" 2 "{it:{&rho}} = 0.1" 3 "{it:{&rho}} = 0.3" ///
			4 "{it:{&rho}} = -0.1" 5 "{it:{&rho}} = -0.3") ring(0) pos(7) region(color(none))) ///
	scheme(tufte)

	gr export ${figdir}/fig_model_corr_Sm.pdf , replace

	
	
	
*** erase files
erase ${data}/sim_model1.dta
erase ${data}/sim_model2.dta