cap cd "C:/Users/laiwz/OneDrive - University of Maryland/Research/anticorruption_civil_servant/jle_final/replication"

global data ./data
global figdir ./figure
global tabdir ./table

graph set window fontface "Times New Roman"




***************************************
** program
** bivariate correlated log normal
***************************************
cap program drop model

program def model , rclass

*** inputs
args ///
	mu_a mu_t ///
	rho0 rho1 rho2 rho3 rho4 ///
	m_lb m_ub w ///
	al p_lb p_ub

*** clear memory
clear
set obs 10000


*** simulate theta and a
forvalues i=0(1)4 {
	
	local r = ln(`rho`i''*(exp(1)-1)+1)
	
	mat sd = (1, 1)
	mat mu = (ln(`mu_a')-0.5 , ln(`mu_t')-0.5)
	mat cor`i' = (1 , `r' \ `r' , 1)
	
	drawnorm x y , means(mu) sds(sd) corr(cor`i') cst(full) // altruism and ability
	gen double a`i' = exp(x)
	gen double t`i' = exp(y)
	
	drop x y
	
}


*** parameterization

// legal income
gen double w = `w'

// m: bureaucratic power
if `m_lb'==`m_ub' {
	gen double m = `m_lb'
}
else {
	gen double m = runiform(`m_lb',`m_ub') in 1 // funds at discretion
	egen double temp = max(m)
	replace m = temp
	drop temp
}

// p: corruption detection
if `p_lb'==`p_ub' {
	gen double p = `p_lb'
}
else {
	gen double p = runiform(`p_lb',`p_ub') in 1 // prob of detecting misconduct
	egen double temp = max(p)
	replace p = temp
	drop temp
}


*** join bureaucracy or not
sum p
local q = `r(mean)'

if 1-(1+`al')*`q'>0 {
	local ahat = 1-(1+`al')*`q'
}
else {
	local ahat = 0
}



foreach i in 0 1 2 3 4 {

gen double x`i' = 1
replace x`i' = ( (1-a`i')/((1+`al')*p) )^(1/`al') if inrange(a`i',`ahat',1)
replace x`i' = 0 if a`i'>1

gen double ub`i' = w + a`i'*(1-x`i')*m + (1-p*(x`i')^`al')*x`i'*m // utitlity if embezzling
gen double un`i' = t`i'
gen double join`i' = (ub`i'>=un`i')


*** statistics
// bureaucrats
sum join`i'
ret scalar ss`i' = `r(mean)' // applicant pool size

sum x`i' if join`i'
ret scalar cc`i' = `r(mean)' // corruption incidence conditional on joinning

sum a`i' if join`i'
ret scalar aa`i' = `r(mean)' // avg bureaucratic altruism

sum t`i' if join`i'
ret scalar tt`i' = `r(mean)' // avg bureaucratic ability

}

// anticorruption policy
sum m
ret scalar mm = `r(mean)' // funds at discretion

sum p
ret scalar pp = `r(mean)' // oversight strength

end





***************************************
**# Figures OA9 a, b, c
**** comparative statics wrt q
***************************************
/// simulattion
/* Variables
args ///
	mu_a mu_t ///
	rho0 rho1 rho2 rho3 rho4 ///
	m_lb m_ub w ///
	al p_lb p_ub
*/
	
simulate , seed(2022) reps(1000) saving(${data}/sim_model1_lognormal , replace) : model ///
	1 1 ///
	0 .1 .3 -.1 -.3 ///
	8 8 0 ///
	2 0 1

	
	

/// plotting
use ${data}/sim_model1_lognormal , clear
global v pp
sort $v

	
tw ///
	(lowess tt0 $v , lw(.5)  mean ) ///
	(lowess tt1 $v , lw(.5)  mean ) ///
	(lowess tt2 $v , lw(.5)  mean ) ///
	(lowess tt3 $v , lw(.5)  mean ) ///
	(lowess tt4 $v , lw(.5)  mean ) , ///
	xlab(, nogr) xti("{it:q}") yti("{it:{&Theta}}") ///
	leg(order(1 "{it:{&rho}} = 0" 2 "{it:{&rho}} = 0.1" 3 "{it:{&rho}} = 0.3" ///
				4 "{it:{&rho}} = -0.1" 5 "{it:{&rho}} = -0.3") ring(0) pos(7) region(color(none))) ///
	scheme(tufte)
	
	gr export ${figdir}/fig_model_corr_Tp_lognormal.pdf , replace


tw ///
	(lowess aa0 $v , lw(.5)  mean ) ///
	(lowess aa1 $v , lw(.5)  mean ) ///
	(lowess aa2 $v , lw(.5)  mean ) ///
	(lowess aa3 $v , lw(.5)  mean ) ///
	(lowess aa4 $v , lw(.5)  mean ) , ///
	xlab(, nogr) xti("{it:q}") yti("{it:A}") ///
	leg(order(1 "{it:{&rho}} = 0" 2 "{it:{&rho}} = 0.1" 3 "{it:{&rho}} = 0.3" ///
				4 "{it:{&rho}} = -0.1" 5 "{it:{&rho}} = -0.3") ring(0) pos(11) region(color(none))) ///
	scheme(tufte)

	gr export ${figdir}/fig_model_corr_Ap_lognormal.pdf , replace
	
	
	
tw ///
	(lowess ss0 $v , lw(.5)  mean ) ///
	(lowess ss1 $v , lw(.5)  mean ) ///
	(lowess ss2 $v , lw(.5)  mean ) ///
	(lowess ss3 $v , lw(.5)  mean ) ///
	(lowess ss4 $v , lw(.5)  mean ) , ///
	xlab(, nogr) xti("{it:q}") yti("{it:S}") ///
	leg(order(1 "{it:{&rho}} = 0" 2 "{it:{&rho}} = 0.1" 3 "{it:{&rho}} = 0.3" ///
				4 "{it:{&rho}} = -0.1" 5 "{it:{&rho}} = -0.3") ring(0) pos(7) region(color(none))) ///
	scheme(tufte)
	
	gr export ${figdir}/fig_model_corr_Sp_lognormal.pdf , replace

	
	

***************************************
**# comparative statics wrt m
***************************************
/*
	mu_a mu_t ///
	rho0 rho1 rho2 rho3 rho4 ///
	m_lb m_ub w ///
	al p_lb p_ub
*/
	
simulate , seed(2022) reps(1000) saving(${data}/sim_model2_lognormal , replace) : model ///
	1 1 ///
	0 .1 .3 -.1 -.3 ///
	1 10 0 ///
	2 .5 .5




/// plotting
use ${data}/sim_model2_lognormal , clear

gen m = -mm
global v m

*pctile pct=$v , nq(50)
*collapse (mean) ss cc aa tt $v , by(pct)
sort $v

	
tw ///
	(lowess tt0 $v , lw(.5)   mean ) ///
	(lowess tt1 $v , lw(.5)   mean ) ///
	(lowess tt2 $v , lw(.5)   mean ) ///
	(lowess tt3 $v , lw(.5)   mean ) ///
	(lowess tt4 $v , lw(.5)   mean ) , ///
	xlab(, nogr) xti("{it:-m}") yti("{it:{&Theta}}") ///
	leg(order(1 "{it:{&rho}} = 0" 2 "{it:{&rho}} = 0.1" 3 "{it:{&rho}} = 0.3" ///
			4 "{it:{&rho}} = -0.1" 5 "{it:{&rho}} = -0.3") ring(0) pos(7) region(color(none))) ///
	scheme(tufte)
	
	gr export ${figdir}/fig_model_corr_Tm_lognormal.pdf , replace
	
	
		
tw ///
	(lowess aa0 $v , lw(.5)   mean ) ///
	(lowess aa1 $v , lw(.5)   mean ) ///
	(lowess aa2 $v , lw(.5)   mean ) ///
	(lowess aa3 $v , lw(.5)   mean ) ///
	(lowess aa4 $v , lw(.5)   mean ) , ///
	xlab(, nogr) xti("{it:-m}") yti("{it:A}" ) ///
	leg(order(1 "{it:{&rho}} = 0" 2 "{it:{&rho}} = 0.1" 3 "{it:{&rho}} = 0.3" ///
			4 "{it:{&rho}} = -0.1" 5 "{it:{&rho}} = -0.3") ring(0) pos(11) region(color(none))) ///
	scheme(tufte)
	
	gr export ${figdir}/fig_model_corr_Am_lognormal.pdf , replace

	
	
tw ///
	(lowess ss0 $v , lw(.5)   mean ) ///
	(lowess ss1 $v , lw(.5)   mean ) ///
	(lowess ss2 $v , lw(.5)   mean ) ///
	(lowess ss3 $v , lw(.5)   mean ) ///
	(lowess ss4 $v , lw(.5)   mean ) , ///
	xlab(, nogr) xti("{it:-m}") yti("{it:S}") ///
	leg(order(1 "{it:{&rho}} = 0" 2 "{it:{&rho}} = 0.1" 3 "{it:{&rho}} = 0.3" ///
			4 "{it:{&rho}} = -0.1" 5 "{it:{&rho}} = -0.3") ring(0) pos(7) region(color(none))) ///
	scheme(tufte)	
	
	gr export ${figdir}/fig_model_corr_Sm_lognormal.pdf , replace
	

	
	
*** erase intermediate files
erase ${data}/sim_model1_lognormal.dta
erase ${data}/sim_model2_lognormal.dta
